@@ -133,7 +133,7 @@ add_denomination (
 enum GNUNET_DB_QueryStatus
 TALER_ARL_get_denomination_info_by_hash (
   const struct TALER_DenominationHashP *dh,
-  const struct TALER_EXCHANGEDB_DenominationKeyInformation **issue)
+  const struct TALER_EXCHANGEDB_DenominationKeyInformation **issuep)
 {
   enum GNUNET_DB_QueryStatus qs;
 
@@ -147,7 +147,7 @@ TALER_ARL_get_denomination_info_by_hash (
     if (0 > qs)
     {
       GNUNET_break (0);
-      *issue = NULL;
+      *issuep = NULL;
       return qs;
     }
   }
@@ -159,7 +159,7 @@ TALER_ARL_get_denomination_info_by_hash (
     if (NULL != i)
     {
       /* cache hit */
-      *issue = i;
+      *issuep = i;
       return GNUNET_DB_STATUS_SUCCESS_ONE_RESULT;
     }
   }
@@ -191,7 +191,7 @@ TALER_ARL_get_denomination_info_by_hash (
     if (NULL != i)
     {
       /* cache hit */
-      *issue = i;
+      *issuep = i;
       return GNUNET_DB_STATUS_SUCCESS_ONE_RESULT;
     }
   }
@@ -615,6 +615,7 @@ TALER_ARL_init (const struct GNUNET_CONFIGURATION_Handle *c)
 
   if (GNUNET_OK !=
       TALER_config_get_currency (TALER_ARL_cfg,
+                                 "exchange",
                                  &TALER_ARL_currency))
   {
     return GNUNET_SYSERR;
@@ -622,19 +623,20 @@ TALER_ARL_init (const struct GNUNET_CONFIGURATION_Handle *c)
   {
     if ( (GNUNET_OK !=
           TALER_config_get_amount (TALER_ARL_cfg,
-                                   "taler",
+                                   "exchange",
                                    "CURRENCY_ROUND_UNIT",
                                    &TALER_ARL_currency_round_unit)) ||
          ( (0 != TALER_ARL_currency_round_unit.fraction) &&
            (0 != TALER_ARL_currency_round_unit.value) ) )
     {
       GNUNET_log (GNUNET_ERROR_TYPE_ERROR,
-                  "Need non-zero value in section `TALER' under `CURRENCY_ROUND_UNIT'\n");
+                  "Need non-zero value in section `exchange' under `CURRENCY_ROUND_UNIT'\n");
       return GNUNET_SYSERR;
     }
   }
   if (NULL ==
-      (TALER_ARL_edb = TALER_EXCHANGEDB_plugin_load (TALER_ARL_cfg)))
+      (TALER_ARL_edb = TALER_EXCHANGEDB_plugin_load (TALER_ARL_cfg,
+                                                     false)))
   {
     GNUNET_log (GNUNET_ERROR_TYPE_ERROR,
                 "Failed to initialize exchange database plugin.\n");
@@ -642,7 +644,8 @@ TALER_ARL_init (const struct GNUNET_CONFIGURATION_Handle *c)
     return GNUNET_SYSERR;
   }
   if (NULL ==
-      (TALER_ARL_adb = TALER_AUDITORDB_plugin_load (TALER_ARL_cfg)))
+      (TALER_ARL_adb = TALER_AUDITORDB_plugin_load (TALER_ARL_cfg,
+                                                    false)))
   {
     GNUNET_log (GNUNET_ERROR_TYPE_ERROR,
                 "Failed to initialize auditor database plugin.\n");
