@@ -13,8 +13,6 @@
    You should have received a copy of the GNU General Public License along with
    TALER; see the file COPYING.  If not, see <http://www.gnu.org/licenses/>
  */
-
-
 #include "platform.h"
 #include <gnunet/gnunet_util_lib.h>
 #include <gnunet/gnunet_json_lib.h>
@@ -28,42 +26,41 @@
 
 
 /**
-* Add emergency to the list.
-*
-* @param[in,out] cls a `json_t *` array to extend
-* @param serial_id location of the @a dc in the database
-* @param dc struct of inconsistencies
-* @return #GNUNET_OK to continue to iterate, #GNUNET_SYSERR to stop iterating
-*/
+ * Add emergency to the list.
+ *
+ * @param[in,out] cls a `json_t *` array to extend
+ * @param dc struct of inconsistencies
+ * @return #GNUNET_OK to continue to iterate, #GNUNET_SYSERR to stop iterating
+ */
 static enum GNUNET_GenericReturnValue
 process_emergency (
   void *cls,
-  uint64_t serial_id,
   const struct TALER_AUDITORDB_Emergency *dc)
 {
   json_t *list = cls;
   json_t *obj;
 
-
   obj = GNUNET_JSON_PACK (
-
-    GNUNET_JSON_pack_int64 ("row_id", serial_id),
-
-    GNUNET_JSON_pack_data_auto ("denompub_h", &dc->denompub_h),
-
-    TALER_JSON_pack_amount ("denom_risk", &dc->denom_risk),
-    TALER_JSON_pack_amount ("denom_loss", &dc->denom_loss),
-
-    TALER_JSON_pack_time_abs_human ("deposit_start", dc->deposit_start),
-    TALER_JSON_pack_time_abs_human ("deposit_end", dc->deposit_end),
-
-    TALER_JSON_pack_amount ("value", &dc->value)
+    GNUNET_JSON_pack_uint64 ("row_id",
+                             dc->row_id),
+    GNUNET_JSON_pack_data_auto ("denompub_h",
+                                &dc->denompub_h),
+    TALER_JSON_pack_amount ("denom_risk",
+                            &dc->denom_risk),
+    TALER_JSON_pack_amount ("denom_loss",
+                            &dc->denom_loss),
+    TALER_JSON_pack_time_abs_human ("deposit_start",
+                                    dc->deposit_start),
+    TALER_JSON_pack_time_abs_human ("deposit_end",
+                                    dc->deposit_end),
+    TALER_JSON_pack_amount ("value",
+                            &dc->value),
+    GNUNET_JSON_pack_bool ("suppressed",
+                           dc->suppressed)
     );
   GNUNET_break (0 ==
                 json_array_append_new (list,
                                        obj));
-
-
   return GNUNET_OK;
 }
 
@@ -79,6 +76,9 @@ TAH_EMERGENCY_handler_get (
 {
   json_t *ja;
   enum GNUNET_DB_QueryStatus qs;
+  int64_t limit = -20;
+  uint64_t offset;
+  bool return_suppressed = false;
 
   (void) rh;
   (void) connection_cls;
@@ -93,27 +93,29 @@ TAH_EMERGENCY_handler_get (
                                        TALER_EC_GENERIC_DB_SETUP_FAILED,
                                        NULL);
   }
-  ja = json_array ();
-  GNUNET_break (NULL != ja);
-
-  int64_t limit = -20;
-  uint64_t offset;
-
   TALER_MHD_parse_request_snumber (connection,
                                    "limit",
                                    &limit);
-
   if (limit < 0)
     offset = INT64_MAX;
   else
     offset = 0;
-
   TALER_MHD_parse_request_number (connection,
                                   "offset",
                                   &offset);
+  {
+    const char *ret_s
+      = MHD_lookup_connection_value (connection,
+                                     MHD_GET_ARGUMENT_KIND,
+                                     "return_suppressed");
+    if (ret_s != NULL && strcmp (ret_s, "true") == 0)
+    {
+      return_suppressed = true;
+    }
+  }
 
-  bool return_suppressed = false;
-
+  ja = json_array ();
+  GNUNET_break (NULL != ja);
   qs = TAH_plugin->get_emergency (
     TAH_plugin->cls,
     limit,
@@ -121,7 +123,6 @@ TAH_EMERGENCY_handler_get (
     return_suppressed,
     &process_emergency,
     ja);
-
   if (0 > qs)
   {
     GNUNET_break (GNUNET_DB_STATUS_HARD_ERROR == qs);
