@@ -13,8 +13,6 @@
    You should have received a copy of the GNU General Public License along with
    TALER; see the file COPYING.  If not, see <http://www.gnu.org/licenses/>
  */
-
-
 #include "platform.h"
 #include <gnunet/gnunet_util_lib.h>
 #include <gnunet/gnunet_json_lib.h>
@@ -30,32 +28,32 @@
  * Add purse-not-closed-inconsistencies to the list.
  *
  * @param[in,out] cls a `json_t *` array to extend
- * @param serial_id location of the @a dc in the database
  * @param dc struct of inconsistencies
  * @return #GNUNET_OK to continue to iterate, #GNUNET_SYSERR to stop iterating
  */
 static enum GNUNET_GenericReturnValue
 process_purse_not_closed_inconsistencies (
   void *cls,
-  uint64_t serial_id,
   const struct TALER_AUDITORDB_PurseNotClosedInconsistencies *dc)
 {
   json_t *list = cls;
   json_t *obj;
 
   obj = GNUNET_JSON_PACK (
-
-    GNUNET_JSON_pack_data_auto ("purse_pub", &dc->purse_pub),
-    TALER_JSON_pack_amount ("amount", &dc->amount),
-    TALER_JSON_pack_time_abs_human ("expiration_date", dc->expiration_date)
-
-
+    GNUNET_JSON_pack_uint64 ("row_id",
+                             dc->row_id),
+    GNUNET_JSON_pack_data_auto ("purse_pub",
+                                &dc->purse_pub),
+    TALER_JSON_pack_amount ("amount",
+                            &dc->amount),
+    TALER_JSON_pack_time_abs_human ("expiration_date",
+                                    dc->expiration_date),
+    GNUNET_JSON_pack_bool ("suppressed",
+                           dc->suppressed)
     );
   GNUNET_break (0 ==
                 json_array_append_new (list,
                                        obj));
-
-
   return GNUNET_OK;
 }
 
@@ -71,6 +69,9 @@ TAH_PURSE_NOT_CLOSED_INCONSISTENCIES_handler_get (
 {
   json_t *ja;
   enum GNUNET_DB_QueryStatus qs;
+  int64_t limit = -20;
+  uint64_t offset;
+  bool return_suppressed = false;
 
   (void) rh;
   (void) connection_cls;
@@ -85,28 +86,33 @@ TAH_PURSE_NOT_CLOSED_INCONSISTENCIES_handler_get (
                                        TALER_EC_GENERIC_DB_SETUP_FAILED,
                                        NULL);
   }
-  ja = json_array ();
-  GNUNET_break (NULL != ja);
-
-  int64_t limit = -20;
-  uint64_t offset;
-
   TALER_MHD_parse_request_snumber (connection,
                                    "limit",
                                    &limit);
-
   if (limit < 0)
     offset = INT64_MAX;
   else
     offset = 0;
-
   TALER_MHD_parse_request_number (connection,
                                   "offset",
                                   &offset);
 
-  bool return_suppressed = false;
+  {
+    const char *ret_s
+      = MHD_lookup_connection_value (connection,
+                                     MHD_GET_ARGUMENT_KIND,
+                                     "return_suppressed");
 
+    if ( (NULL != ret_s) &&
+         (0 == strcmp (ret_s,
+                       "true")) )
+    {
+      return_suppressed = true;
+    }
+  }
 
+  ja = json_array ();
+  GNUNET_break (NULL != ja);
   qs = TAH_plugin->get_purse_not_closed_inconsistencies (
     TAH_plugin->cls,
     limit,
@@ -129,6 +135,6 @@ TAH_PURSE_NOT_CLOSED_INCONSISTENCIES_handler_get (
   return TALER_MHD_REPLY_JSON_PACK (
     connection,
     MHD_HTTP_OK,
-    GNUNET_JSON_pack_array_steal ("purse-not-closed-inconsistencies",
+    GNUNET_JSON_pack_array_steal ("purse_not_closed_inconsistencies",
                                   ja));
 }
