@@ -49,6 +49,7 @@ static int test_mode;
  */
 static TALER_ARL_DEF_PP (purse_account_merge_serial_id);
 static TALER_ARL_DEF_PP (purse_decision_serial_id);
+static TALER_ARL_DEF_PP (purse_deletion_serial_id);
 static TALER_ARL_DEF_PP (purse_deposits_serial_id);
 static TALER_ARL_DEF_PP (purse_merges_serial_id);
 static TALER_ARL_DEF_PP (purse_request_serial_id);
@@ -325,15 +326,16 @@ struct PurseSummary
   bool had_pi;
 
   /**
-   * Was the purse deleted?  FIXME: Not yet handled (do we need to? purse
-   * might just appear as expired eventually; but in the meantime, exchange
-   * may seem to have refunded the coins for no good reason...), also we do
-   * not yet check the deletion signature.
+   * Was the purse deleted? Note: as this is set via an UPDATE, it
+   * may be false at the auditor even if the purse was deleted. Thus,
+   * this value is only meaningful for *internal* checks.
    */
   bool purse_deleted;
 
   /**
-   * Was the purse refunded? FIXME: Not yet handled (do we need to?)
+   * Was the purse refunded? Note: as this is set via an UPDATE, it
+   * may be false at the auditor even if the purse was deleted. Thus,
+   * this value is only meaningful for *internal* checks.
    */
   bool purse_refunded;
 
@@ -401,7 +403,7 @@ struct PurseContext
 
 
 /**
- * Create a new reserve for @a reserve_pub in @a rc.
+ * Create a new purse for @a purse_pub in @a pc.
  *
  * @param[in,out] pc context to update
  * @param purse_pub key for which to create a purse
@@ -987,6 +989,20 @@ handle_purse_decision (
         return GNUNET_SYSERR;
       }
     }
+    if ( (internal_checks) &&
+         (! ps->purse_refunded) )
+    {
+      qs = report_row_inconsistency (
+        "purse-decision",
+        rowid,
+        "purse not marked as refunded (internal check)");
+      if (qs < 0)
+      {
+        GNUNET_break (GNUNET_DB_STATUS_SOFT_ERROR == qs);
+        pc->qs = qs;
+        return GNUNET_SYSERR;
+      }
+    }
   }
   else
   {
@@ -1032,6 +1048,67 @@ handle_purse_decision (
 }
 
 
+/**
+ * Function called on explicitly deleted purses.
+ *
+ * @param cls closure
+ * @param deletion_serial_id row ID with the deletion data
+ * @param purse_pub public key of the purse
+ * @param purse_sig signature affirming deletion of the purse
+ * @return #GNUNET_OK to continue to iterate
+ */
+static enum GNUNET_GenericReturnValue
+handle_purse_deletion (
+  void *cls,
+  uint64_t deletion_serial_id,
+  const struct TALER_PurseContractPublicKeyP *purse_pub,
+  const struct TALER_PurseContractSignatureP *purse_sig)
+{
+  struct PurseContext *pc = cls;
+  struct PurseSummary *ps;
+
+  ps = setup_purse (pc,
+                    purse_pub);
+  if (GNUNET_OK !=
+      TALER_wallet_purse_delete_verify (purse_pub,
+                                        purse_sig))
+  {
+    enum GNUNET_DB_QueryStatus qs;
+
+    qs = report_row_inconsistency (
+      "purse-delete",
+      deletion_serial_id,
+      "purse deletion signature invalid");
+    if (qs < 0)
+    {
+      GNUNET_break (GNUNET_DB_STATUS_SOFT_ERROR == qs);
+      pc->qs = qs;
+      return GNUNET_SYSERR;
+    }
+  }
+  else
+  {
+    if ( (internal_checks) &&
+         (! ps->purse_deleted) )
+    {
+      enum GNUNET_DB_QueryStatus qs;
+
+      qs = report_row_inconsistency (
+        "purse-delete",
+        deletion_serial_id,
+        "purse not marked as deleted (internal check)");
+      if (qs < 0)
+      {
+        GNUNET_break (GNUNET_DB_STATUS_SOFT_ERROR == qs);
+        pc->qs = qs;
+        return GNUNET_SYSERR;
+      }
+    }
+  }
+  return GNUNET_OK;
+}
+
+
 /**
  * Function called on expired purses.
  *
@@ -1056,7 +1133,6 @@ handle_purse_expired (
     .purse_pub = purse_pub->eddsa_pub
   };
 
-  (void) pc;
   qs = TALER_ARL_adb->insert_purse_not_closed_inconsistencies (
     TALER_ARL_adb->cls,
     &pnci);
@@ -1203,6 +1279,8 @@ analyze_purses (void *cls)
 {
   struct PurseContext pc;
   enum GNUNET_DB_QueryStatus qs;
+  bool had_pp;
+  bool had_bal;
 
   (void) cls;
   GNUNET_log (GNUNET_ERROR_TYPE_DEBUG,
@@ -1211,6 +1289,7 @@ analyze_purses (void *cls)
     TALER_ARL_adb->cls,
     TALER_ARL_GET_PP (purse_account_merge_serial_id),
     TALER_ARL_GET_PP (purse_decision_serial_id),
+    TALER_ARL_GET_PP (purse_deletion_serial_id),
     TALER_ARL_GET_PP (purse_deposits_serial_id),
     TALER_ARL_GET_PP (purse_merges_serial_id),
     TALER_ARL_GET_PP (purse_request_serial_id),
@@ -1221,19 +1300,17 @@ analyze_purses (void *cls)
     GNUNET_break (GNUNET_DB_STATUS_SOFT_ERROR == qs);
     return qs;
   }
-  if (GNUNET_DB_STATUS_SUCCESS_NO_RESULTS == qs)
-  {
-    GNUNET_log (GNUNET_ERROR_TYPE_MESSAGE,
-                "First analysis using this auditor, starting audit from scratch\n");
-  }
-  else
+  had_pp = (GNUNET_DB_STATUS_SUCCESS_ONE_RESULT == qs);
+  if (had_pp)
   {
     GNUNET_log (GNUNET_ERROR_TYPE_INFO,
-                "Resuming purse audit at %llu/%llu/%llu/%llu/%llu\n",
+                "Resuming purse audit at %llu/%llu/%llu/%llu/%llu/%llu\n",
                 (unsigned long long) TALER_ARL_USE_PP (
                   purse_request_serial_id),
                 (unsigned long long) TALER_ARL_USE_PP (
                   purse_decision_serial_id),
+                (unsigned long long) TALER_ARL_USE_PP (
+                  purse_deletion_serial_id),
                 (unsigned long long) TALER_ARL_USE_PP (
                   purse_merges_serial_id),
                 (unsigned long long) TALER_ARL_USE_PP (
@@ -1241,6 +1318,11 @@ analyze_purses (void *cls)
                 (unsigned long long) TALER_ARL_USE_PP (
                   purse_account_merge_serial_id));
   }
+  else
+  {
+    GNUNET_log (GNUNET_ERROR_TYPE_MESSAGE,
+                "First analysis using this auditor, starting audit from scratch\n");
+  }
   pc.qs = GNUNET_DB_STATUS_SUCCESS_ONE_RESULT;
   qs = TALER_ARL_adb->get_balance (
     TALER_ARL_adb->cls,
@@ -1257,6 +1339,7 @@ analyze_purses (void *cls)
     GNUNET_break (GNUNET_DB_STATUS_SOFT_ERROR == qs);
     return qs;
   }
+  had_bal = (GNUNET_DB_STATUS_SUCCESS_ONE_RESULT == qs);
   pc.purses = GNUNET_CONTAINER_multihashmap_create (512,
                                                     GNUNET_NO);
 
@@ -1340,6 +1423,22 @@ analyze_purses (void *cls)
     return pc.qs;
   }
 
+  qs = TALER_ARL_edb->select_all_purse_deletions_above_serial_id (
+    TALER_ARL_edb->cls,
+    TALER_ARL_USE_PP (purse_deletion_serial_id),
+    &handle_purse_deletion,
+    &pc);
+  if (qs < 0)
+  {
+    GNUNET_break (GNUNET_DB_STATUS_SOFT_ERROR == qs);
+    return qs;
+  }
+  if (pc.qs < 0)
+  {
+    GNUNET_break (GNUNET_DB_STATUS_SOFT_ERROR == pc.qs);
+    return pc.qs;
+  }
+
   qs = TALER_ARL_adb->select_purse_expired (
     TALER_ARL_adb->cls,
     &handle_purse_expired,
@@ -1369,17 +1468,28 @@ analyze_purses (void *cls)
     GNUNET_break (GNUNET_DB_STATUS_SOFT_ERROR == pc.qs);
     return pc.qs;
   }
-
-  qs = TALER_ARL_adb->insert_balance (
-    TALER_ARL_adb->cls,
-    TALER_ARL_SET_AB (purse_global_balance),
-    TALER_ARL_SET_AB (purse_total_balance_insufficient_loss),
-    TALER_ARL_SET_AB (purse_total_delayed_decisions),
-    TALER_ARL_SET_AB (purse_total_balance_purse_not_closed),
-    TALER_ARL_SET_AB (purse_total_arithmetic_delta_plus),
-    TALER_ARL_SET_AB (purse_total_arithmetic_delta_minus),
-    TALER_ARL_SET_AB (purse_total_bad_sig_loss),
-    NULL);
+  if (had_bal)
+    qs = TALER_ARL_adb->update_balance (
+      TALER_ARL_adb->cls,
+      TALER_ARL_SET_AB (purse_global_balance),
+      TALER_ARL_SET_AB (purse_total_balance_insufficient_loss),
+      TALER_ARL_SET_AB (purse_total_delayed_decisions),
+      TALER_ARL_SET_AB (purse_total_balance_purse_not_closed),
+      TALER_ARL_SET_AB (purse_total_arithmetic_delta_plus),
+      TALER_ARL_SET_AB (purse_total_arithmetic_delta_minus),
+      TALER_ARL_SET_AB (purse_total_bad_sig_loss),
+      NULL);
+  else
+    qs = TALER_ARL_adb->insert_balance (
+      TALER_ARL_adb->cls,
+      TALER_ARL_SET_AB (purse_global_balance),
+      TALER_ARL_SET_AB (purse_total_balance_insufficient_loss),
+      TALER_ARL_SET_AB (purse_total_delayed_decisions),
+      TALER_ARL_SET_AB (purse_total_balance_purse_not_closed),
+      TALER_ARL_SET_AB (purse_total_arithmetic_delta_plus),
+      TALER_ARL_SET_AB (purse_total_arithmetic_delta_minus),
+      TALER_ARL_SET_AB (purse_total_bad_sig_loss),
+      NULL);
   if (0 > qs)
   {
     GNUNET_log (GNUNET_ERROR_TYPE_INFO,
@@ -1387,51 +1497,28 @@ analyze_purses (void *cls)
     GNUNET_break (GNUNET_DB_STATUS_SOFT_ERROR == qs);
     return qs;
   }
-
-  qs = TALER_ARL_adb->update_balance (
-    TALER_ARL_adb->cls,
-    TALER_ARL_SET_AB (purse_global_balance),
-    TALER_ARL_SET_AB (purse_total_balance_insufficient_loss),
-    TALER_ARL_SET_AB (purse_total_delayed_decisions),
-    TALER_ARL_SET_AB (purse_total_balance_purse_not_closed),
-    TALER_ARL_SET_AB (purse_total_arithmetic_delta_plus),
-    TALER_ARL_SET_AB (purse_total_arithmetic_delta_minus),
-    TALER_ARL_SET_AB (purse_total_bad_sig_loss),
-    NULL);
-  if (0 > qs)
-  {
-    GNUNET_log (GNUNET_ERROR_TYPE_INFO,
-                "Failed to update auditor DB, not recording progress\n");
-    GNUNET_break (GNUNET_DB_STATUS_SOFT_ERROR == qs);
-    return qs;
-  }
-
-  qs = TALER_ARL_adb->insert_auditor_progress (
-    TALER_ARL_adb->cls,
-    TALER_ARL_SET_PP (purse_account_merge_serial_id),
-    TALER_ARL_SET_PP (purse_decision_serial_id),
-    TALER_ARL_SET_PP (purse_deposits_serial_id),
-    TALER_ARL_SET_PP (purse_merges_serial_id),
-    TALER_ARL_SET_PP (purse_request_serial_id),
-    TALER_ARL_SET_PP (purse_open_counter),
-    NULL);
-  if (0 > qs)
-  {
-    GNUNET_log (GNUNET_ERROR_TYPE_INFO,
-                "Failed to update auditor DB, not recording progress\n");
-    GNUNET_break (GNUNET_DB_STATUS_SOFT_ERROR == qs);
-    return qs;
-  }
-
-  qs = TALER_ARL_adb->update_auditor_progress (
-    TALER_ARL_adb->cls,
-    TALER_ARL_SET_PP (purse_account_merge_serial_id),
-    TALER_ARL_SET_PP (purse_decision_serial_id),
-    TALER_ARL_SET_PP (purse_deposits_serial_id),
-    TALER_ARL_SET_PP (purse_merges_serial_id),
-    TALER_ARL_SET_PP (purse_request_serial_id),
-    TALER_ARL_SET_PP (purse_open_counter),
-    NULL);
+  if (had_pp)
+    qs = TALER_ARL_adb->update_auditor_progress (
+      TALER_ARL_adb->cls,
+      TALER_ARL_SET_PP (purse_account_merge_serial_id),
+      TALER_ARL_SET_PP (purse_decision_serial_id),
+      TALER_ARL_SET_PP (purse_deletion_serial_id),
+      TALER_ARL_SET_PP (purse_deposits_serial_id),
+      TALER_ARL_SET_PP (purse_merges_serial_id),
+      TALER_ARL_SET_PP (purse_request_serial_id),
+      TALER_ARL_SET_PP (purse_open_counter),
+      NULL);
+  else
+    qs = TALER_ARL_adb->insert_auditor_progress (
+      TALER_ARL_adb->cls,
+      TALER_ARL_SET_PP (purse_account_merge_serial_id),
+      TALER_ARL_SET_PP (purse_decision_serial_id),
+      TALER_ARL_SET_PP (purse_deletion_serial_id),
+      TALER_ARL_SET_PP (purse_deposits_serial_id),
+      TALER_ARL_SET_PP (purse_merges_serial_id),
+      TALER_ARL_SET_PP (purse_request_serial_id),
+      TALER_ARL_SET_PP (purse_open_counter),
+      NULL);
   if (0 > qs)
   {
     GNUNET_log (GNUNET_ERROR_TYPE_INFO,
@@ -1440,11 +1527,13 @@ analyze_purses (void *cls)
     return qs;
   }
   GNUNET_log (GNUNET_ERROR_TYPE_INFO,
-              "Concluded purse audit step at %llu/%llu/%llu/%llu/%llu\n",
+              "Concluded purse audit step at %llu/%llu/%llu/%llu/%llu/%llu\n",
               (unsigned long long) TALER_ARL_USE_PP (
                 purse_request_serial_id),
               (unsigned long long) TALER_ARL_USE_PP (
                 purse_decision_serial_id),
+              (unsigned long long) TALER_ARL_USE_PP (
+                purse_deletion_serial_id),
               (unsigned long long) TALER_ARL_USE_PP (
                 purse_merges_serial_id),
               (unsigned long long) TALER_ARL_USE_PP (
