@@ -863,6 +863,7 @@ get_closing_fee (const struct TALER_FullPayto receiver_account,
   struct GNUNET_TIME_Timestamp end_date;
   struct TALER_WireFeeSet fees;
   char *method;
+  uint64_t rowid;
 
   method = TALER_payto_get_method (receiver_account.full_payto);
   GNUNET_log (GNUNET_ERROR_TYPE_DEBUG,
@@ -872,6 +873,7 @@ get_closing_fee (const struct TALER_FullPayto receiver_account,
       TALER_ARL_edb->get_wire_fee (TALER_ARL_edb->cls,
                                    method,
                                    atime,
+                                   &rowid,
                                    &start_date,
                                    &end_date,
                                    &fees,
@@ -884,7 +886,7 @@ get_closing_fee (const struct TALER_FullPayto receiver_account,
                      method,
                      GNUNET_TIME_timestamp2s (atime));
     report_row_inconsistency ("closing-fee",
-                              atime.abs_time.abs_value_us,
+                              rowid,
                               diag);
     GNUNET_free (diag);
     GNUNET_free (method);
@@ -1391,6 +1393,7 @@ verify_reserve_balance (void *cls,
     GNUNET_assert (GNUNET_OK ==
                    TALER_amount_set_zero (TALER_ARL_currency,
                                           &rs->curr_balance.reserve_balance));
+    nbalance = rs->curr_balance.reserve_balance;
   }
   else
   {
@@ -1565,13 +1568,6 @@ verify_reserve_balance (void *cls,
     else
     {
       /* We failed to determine the closing fee, complain! */
-      // FIXME: fix correctly and not just comment out
-      // nbalance is set to invalid and there is never a check happening when working further with nbalance,
-      // why so and why adding those balances here? or what's the usecase of setting nbalance to zero?
-      /*
-        TALER_ARL_amount_add (&TALER_ARL_USE_AB(total_balance_reserve_not_closed),
-        &TALER_ARL_USE_AB(total_balance_reserve_not_closed),
-                            &nbalance);*/
       struct TALER_AUDITORDB_ReserveNotClosedInconsistency rncid = {
         .reserve_pub = rs->reserve_pub,
         .balance = nbalance,
@@ -1579,6 +1575,13 @@ verify_reserve_balance (void *cls,
         .diagnostic = (char *) "could not determine closing fee"
       };
 
+      /* Even if we don't know the closing fee, update the
+         total_balance_reserve_not_closed */
+      TALER_ARL_amount_add (&TALER_ARL_USE_AB (
+                              total_balance_reserve_not_closed),
+                            &TALER_ARL_USE_AB (
+                              total_balance_reserve_not_closed),
+                            &nbalance);
       qs = TALER_ARL_adb->insert_reserve_not_closed_inconsistency (
         TALER_ARL_adb->cls,
         &rncid);
