@@ -49,10 +49,15 @@ static TALER_ARL_DEF_PP (wire_batch_deposit_id);
 static TALER_ARL_DEF_PP (wire_aggregation_id);
 
 /**
- * Total amount which the exchange did not transfer in time.
+ * Total amount which the exchange did not aggregate/transfer in time.
  */
 static TALER_ARL_DEF_AB (total_amount_lag);
 
+/**
+ * Total amount which the exchange did aggregate/transfer too early.
+ */
+static TALER_ARL_DEF_AB (total_early_aggregation);
+
 /**
  * Should we run checks that only work for exchange-internal audits?
  */
@@ -131,20 +136,43 @@ import_wire_missing_cb (
     return; /* already failed */
   GNUNET_assert (batch_deposit_serial_id >= wc->max_batch_deposit_uuid);
   wc->max_batch_deposit_uuid = batch_deposit_serial_id + 1;
-  qs = TALER_ARL_adb->insert_pending_deposit (
+  qs = TALER_ARL_adb->delete_early_aggregation (
     TALER_ARL_adb->cls,
-    batch_deposit_serial_id,
-    wire_target_h_payto,
-    total_amount,
-    deadline);
-  if (qs < 0)
+    batch_deposit_serial_id);
+  switch (qs)
   {
-    GNUNET_break (GNUNET_DB_STATUS_SOFT_ERROR == qs);
+  case GNUNET_DB_STATUS_SOFT_ERROR:
+    GNUNET_break (0);
     wc->err = qs;
+    return;
+  case GNUNET_DB_STATUS_HARD_ERROR:
+    GNUNET_break (0);
+    wc->err = qs;
+    return;
+  case GNUNET_DB_STATUS_SUCCESS_NO_RESULTS:
+    qs = TALER_ARL_adb->insert_pending_deposit (
+      TALER_ARL_adb->cls,
+      batch_deposit_serial_id,
+      wire_target_h_payto,
+      total_amount,
+      deadline);
+    if (0 < qs)
+    {
+      GNUNET_break (GNUNET_DB_STATUS_SOFT_ERROR == qs);
+      wc->err = qs;
+    }
+    TALER_ARL_amount_add (&TALER_ARL_USE_AB (total_amount_lag),
+                          &TALER_ARL_USE_AB (total_amount_lag),
+                          total_amount);
+    break;
+  case GNUNET_DB_STATUS_SUCCESS_ONE_RESULT:
+    TALER_ARL_amount_subtract (&TALER_ARL_USE_AB (total_early_aggregation),
+                               &TALER_ARL_USE_AB (total_early_aggregation),
+                               total_amount);
+    break;
+  default:
+    GNUNET_assert (0);
   }
-  TALER_ARL_amount_add (&TALER_ARL_USE_AB (total_amount_lag),
-                        &TALER_ARL_USE_AB (total_amount_lag),
-                        total_amount);
 }
 
 
@@ -225,22 +253,40 @@ clear_finished_transfer_cb (
   qs = TALER_ARL_adb->delete_pending_deposit (
     TALER_ARL_adb->cls,
     batch_deposit_serial_id);
-  if (0 == qs)
+  switch (qs)
   {
-    /* Aggregated something twice or other error, report! */
+  case GNUNET_DB_STATUS_SOFT_ERROR:
     GNUNET_break (0);
-    // FIXME: report more nicely!
-    return;
-  }
-  if (0 > qs)
-  {
-    GNUNET_break (GNUNET_DB_STATUS_SOFT_ERROR == qs);
     ac->err = qs;
     return;
+  case GNUNET_DB_STATUS_HARD_ERROR:
+    GNUNET_break (0);
+    ac->err = qs;
+    return;
+  case GNUNET_DB_STATUS_SUCCESS_NO_RESULTS:
+    qs = TALER_ARL_adb->insert_early_aggregation (
+      TALER_ARL_adb->cls,
+      batch_deposit_serial_id,
+      tracking_serial_id,
+      amount);
+    if (0 > qs)
+    {
+      GNUNET_break (GNUNET_DB_STATUS_SOFT_ERROR == qs);
+      ac->err = qs;
+      return;
+    }
+    TALER_ARL_amount_add (&TALER_ARL_USE_AB (total_early_aggregation),
+                          &TALER_ARL_USE_AB (total_early_aggregation),
+                          amount);
+    break;
+  case GNUNET_DB_STATUS_SUCCESS_ONE_RESULT:
+    TALER_ARL_amount_subtract (&TALER_ARL_USE_AB (total_amount_lag),
+                               &TALER_ARL_USE_AB (total_amount_lag),
+                               amount);
+    break;
+  default:
+    GNUNET_assert (0);
   }
-  TALER_ARL_amount_subtract (&TALER_ARL_USE_AB (total_amount_lag),
-                             &TALER_ARL_USE_AB (total_amount_lag),
-                             amount);
 }
 
 
@@ -328,6 +374,7 @@ begin_transaction (void)
   qs = TALER_ARL_adb->get_balance (
     TALER_ARL_adb->cls,
     TALER_ARL_GET_AB (total_amount_lag),
+    TALER_ARL_GET_AB (total_early_aggregation),
     NULL);
   if (0 > qs)
     goto handle_db_error;
@@ -368,12 +415,14 @@ begin_transaction (void)
   qs = TALER_ARL_adb->update_balance (
     TALER_ARL_adb->cls,
     TALER_ARL_SET_AB (total_amount_lag),
+    TALER_ARL_SET_AB (total_early_aggregation),
     NULL);
   if (0 > qs)
     goto handle_db_error;
   qs = TALER_ARL_adb->insert_balance (
     TALER_ARL_adb->cls,
     TALER_ARL_SET_AB (total_amount_lag),
+    TALER_ARL_SET_AB (total_early_aggregation),
     NULL);
   if (0 > qs)
     goto handle_db_error;
@@ -487,7 +536,7 @@ run (void *cls,
   }
   if (0 == test_mode)
   {
-    // FIXME: use different event type in the future!
+    // FIXME-Optimization: use different event type in the future!
     struct GNUNET_DB_EventHeaderP es = {
       .size = htons (sizeof (es)),
       .type = htons (TALER_DBEVENT_EXCHANGE_AUDITOR_WAKE_HELPER_WIRE)
@@ -538,7 +587,7 @@ main (int argc,
     argv,
     "taler-helper-auditor-transfer",
     gettext_noop (
-      "Audit exchange database for consistency of transfers with respect to deposit deadlines"),
+      "Audit exchange database for consistency of aggregations/transfers with respect to deposit deadlines"),
     options,
     &run,
     NULL);
