@@ -326,6 +326,35 @@ static enum GNUNET_DB_QueryStatus
 begin_transaction (void);
 
 
+/**
+ * Rollback the current transaction, reset our state and try
+ * again (we had a serialization error).
+ */
+static void
+rollback_and_reset (void)
+{
+  GNUNET_log (GNUNET_ERROR_TYPE_INFO,
+              "Serialization issue, trying again\n");
+  TALER_ARL_adb->rollback (TALER_ARL_adb->cls);
+  GNUNET_CONTAINER_multihashmap_iterate (in_map,
+                                         &free_rii,
+                                         NULL);
+  GNUNET_CONTAINER_multihashmap_destroy (in_map);
+  in_map = NULL;
+  for (unsigned int max_retries = 3; max_retries>0; max_retries--)
+  {
+    enum GNUNET_DB_QueryStatus qs;
+
+    qs = begin_transaction ();
+    if (GNUNET_DB_STATUS_HARD_ERROR == qs)
+      break;
+  }
+  GNUNET_log (GNUNET_ERROR_TYPE_ERROR,
+              "Hard database error, terminating\n");
+  GNUNET_SCHEDULER_shutdown ();
+}
+
+
 /**
  * Commit the transaction, checkpointing our progress in the auditor DB.
  *
@@ -400,18 +429,7 @@ commit (enum GNUNET_DB_QueryStatus qs)
     GNUNET_SCHEDULER_shutdown ();
   return;
 handle_db_error:
-  TALER_ARL_adb->rollback (TALER_ARL_adb->cls);
-  for (unsigned int max_retries = 3; max_retries>0; max_retries--)
-  {
-    if (GNUNET_DB_STATUS_HARD_ERROR == qs)
-      break;
-    GNUNET_log (GNUNET_ERROR_TYPE_INFO,
-                "Serialization issue, trying again\n");
-    qs = begin_transaction ();
-  }
-  GNUNET_log (GNUNET_ERROR_TYPE_ERROR,
-              "Hard database error, terminating\n");
-  GNUNET_SCHEDULER_shutdown ();
+  rollback_and_reset ();
 }
 
 
@@ -638,7 +656,7 @@ complain_in_not_found (void *cls,
     .bank_row_id = rii->rowid,
     .diagnostic = (char *)
                   "incoming wire transfer claimed by exchange not found",
-    .account.full_payto = (char *) wa->ai->section_name,
+    .account = wa->ai->payto_uri,
     .amount_exchange_expected = rii->credit_details.amount,
     .amount_wired = zero,
     .reserve_pub = rii->credit_details.details.reserve.reserve_pub,
@@ -781,7 +799,7 @@ analyze_credit (
       .amount_wired = zero,
       .reserve_pub = rii->credit_details.details.reserve.reserve_pub,
       .timestamp = rii->credit_details.execution_date.abs_time,
-      .account.full_payto = (char *) wa->ai->section_name,              /* FIXME: get actual account? */
+      .account = wa->ai->payto_uri,
       .diagnostic = (char *) "wire subject does not match"
     };
     enum GNUNET_DB_QueryStatus qs;
@@ -814,7 +832,7 @@ analyze_credit (
   {
     struct TALER_AUDITORDB_ReserveInInconsistency riiDb = {
       .diagnostic = (char *) "wire amount does not match",
-      .account.full_payto = (char *) wa->ai->section_name, /* FIXME: get actual account! */
+      .account = wa->ai->payto_uri,
       .bank_row_id = credit_details->serial_id,
       .amount_exchange_expected = rii->credit_details.amount,
       .amount_wired = credit_details->amount,
@@ -955,13 +973,20 @@ history_credit_cb (void *cls,
       if (! analyze_credit (wa,
                             cd))
       {
-        if (global_qs < 0)
+        switch (global_qs)
         {
-          /* FIXME: this error handling sucks,
-             doesn't retry on SOFT errors, doesn't
-             set global_ret, etc. */
+        case GNUNET_DB_STATUS_SOFT_ERROR:
+          rollback_and_reset ();
+          return;
+        case GNUNET_DB_STATUS_HARD_ERROR:
           GNUNET_SCHEDULER_shutdown ();
           return;
+        case GNUNET_DB_STATUS_SUCCESS_NO_RESULTS:
+          /* perfectly fine */
+          break;
+        case GNUNET_DB_STATUS_SUCCESS_ONE_RESULT:
+          /* perfectly fine */
+          break;
         }
         break;
       }
