@@ -458,8 +458,6 @@ check_pending_rc (void *cls,
     };
     enum GNUNET_DB_QueryStatus qs;
 
-    /* FIXME: where do we *undo* this if the wire transfer is
-       found later? */
     qs = TALER_ARL_adb->insert_auditor_closure_lags (
       TALER_ARL_adb->cls,
       &cl);
@@ -469,8 +467,6 @@ check_pending_rc (void *cls,
       GNUNET_break (GNUNET_DB_STATUS_SOFT_ERROR == qs);
       return GNUNET_SYSERR;
     }
-    /* FIXME: where do we *undo* this if the wire transfer is
-       found later? */
     TALER_ARL_amount_add (&TALER_ARL_USE_AB (total_closure_amount_lag),
                           &TALER_ARL_USE_AB (total_closure_amount_lag),
                           &rc->amount);
@@ -976,6 +972,41 @@ check_profit_drain (struct ReserveOutInfo *roi)
 }
 
 
+/**
+ * Check whether the given transfer was justified because it was
+ * actually previously reported as missing.
+ *
+ * @param roi the reserve out operation to check
+ * @return #GNUNET_OK on success, #GNUNET_NO if there was no
+ *   matching lag, #GNUNET_SYSERR on database trouble
+ */
+static enum GNUNET_GenericReturnValue
+check_closure_lag (const struct ReserveOutInfo *roi)
+{
+  enum GNUNET_DB_QueryStatus qs;
+
+  qs = TALER_ARL_adb->delete_auditor_closure_lag (
+    TALER_ARL_adb->cls,
+    &roi->details.amount,
+    &roi->details.wtid,
+    roi->details.credit_account_uri);
+  if (qs < 0)
+  {
+    global_qs = qs;
+    GNUNET_break (GNUNET_DB_STATUS_SOFT_ERROR == qs);
+    return GNUNET_SYSERR;
+  }
+  if (GNUNET_DB_STATUS_SUCCESS_NO_RESULTS == qs)
+    return GNUNET_NO;
+  GNUNET_log (GNUNET_ERROR_TYPE_INFO,
+              "Cleared closure lag: found justification\n");
+  TALER_ARL_amount_subtract (&TALER_ARL_USE_AB (total_closure_amount_lag),
+                             &TALER_ARL_USE_AB (total_closure_amount_lag),
+                             &roi->details.amount);
+  return GNUNET_YES; /* found! */
+}
+
+
 /**
  * Check whether the given transfer was justified by a reserve closure or
  * profit drain. If not, complain that we failed to match an entry from
@@ -1022,7 +1053,9 @@ complain_out_not_found (void *cls,
   ret = check_profit_drain (roi);
   if (GNUNET_NO != ret)
     return ret;
-
+  ret = check_closure_lag (roi);
+  if (GNUNET_NO != ret)
+    return ret;
 
   {
     struct TALER_AUDITORDB_WireOutInconsistency woi = {
