@@ -13,10 +13,8 @@
    You should have received a copy of the GNU General Public License along with
    TALER; see the file COPYING.  If not, see <http://www.gnu.org/licenses/>
  */
-
-
-#ifndef SRC_PG_GET_DENOMINATION_PENDING_H
-#define SRC_PG_GET_DENOMINATION_PENDING_H
+#ifndef PG_GET_DENOMINATION_PENDING_H
+#define PG_GET_DENOMINATION_PENDING_H
 
 #include "taler_util.h"
 #include "taler_json_lib.h"
@@ -26,9 +24,8 @@
  * Get information about denomination-pending from the database.
  *
  * @param cls the @e cls of this struct with the plugin-specific state
- * @param start_id row/serial ID where to start the iteration (0 from
- *                  the start, exclusive, i.e. serial_ids must start from 1)
- * @param return_suppressed should suppressed rows be returned anyway?
+ * @param limit number of records to return, negative for descending
+ * @param offset table row to start from, exclusive, direction determined by @a limit
  * @param cb function to call with results
  * @param cb_cls closure for @a cb
  * @return query result status
@@ -38,8 +35,7 @@ TAH_PG_get_denomination_pending (
   void *cls,
   int64_t limit,
   uint64_t offset,
-  bool return_suppressed,
   TALER_AUDITORDB_DenominationPendingCallback cb,
   void *cb_cls);
 
-#endif // SRC_PG_GET_DENOMINATION_PENDING_H
+#endif
