@@ -13,16 +13,14 @@
    You should have received a copy of the GNU General Public License along with
    TALER; see the file COPYING.  If not, see <http://www.gnu.org/licenses/>
  */
-
-
 #include "platform.h"
 #include "taler_error_codes.h"
 #include "taler_dbevents.h"
 #include "taler_pq_lib.h"
 #include "pg_helper.h"
-
 #include "pg_get_emergency_by_count.h"
 
+
 /**
  * Closure for #emergency_cb().
  */
@@ -70,17 +68,26 @@ emergency_by_count_cb (void *cls,
 
   for (unsigned int i = 0; i < num_results; i++)
   {
-    uint64_t serial_id;
     struct TALER_AUDITORDB_EmergenciesByCount dc;
     struct GNUNET_PQ_ResultSpec rs[] = {
-      GNUNET_PQ_result_spec_uint64 ("row_id", &serial_id),
-      GNUNET_PQ_result_spec_auto_from_type ("denompub_h",  &dc.denompub_h),
-      GNUNET_PQ_result_spec_uint64 ("num_issued", &dc.num_issued),
-      GNUNET_PQ_result_spec_uint64 ("num_known", &dc.num_known),
-      TALER_PQ_RESULT_SPEC_AMOUNT ("risk", &dc.risk),
-      GNUNET_PQ_result_spec_absolute_time ("start", &dc.start),
-      GNUNET_PQ_result_spec_absolute_time ("deposit_end", &dc.deposit_end),
-      TALER_PQ_RESULT_SPEC_AMOUNT ("value",  &dc.value),
+      GNUNET_PQ_result_spec_uint64 ("row_id",
+                                    &dc.row_id),
+      GNUNET_PQ_result_spec_auto_from_type ("denompub_h",
+                                            &dc.denompub_h),
+      GNUNET_PQ_result_spec_uint64 ("num_issued",
+                                    &dc.num_issued),
+      GNUNET_PQ_result_spec_uint64 ("num_known",
+                                    &dc.num_known),
+      TALER_PQ_RESULT_SPEC_AMOUNT ("risk",
+                                   &dc.risk),
+      GNUNET_PQ_result_spec_absolute_time ("start",
+                                           &dc.start),
+      GNUNET_PQ_result_spec_absolute_time ("deposit_end",
+                                           &dc.deposit_end),
+      TALER_PQ_RESULT_SPEC_AMOUNT ("value",
+                                   &dc.value),
+      GNUNET_PQ_result_spec_bool ("suppressed",
+                                  &dc.suppressed),
       GNUNET_PQ_result_spec_end
     };
     enum GNUNET_GenericReturnValue rval;
@@ -96,7 +103,6 @@ emergency_by_count_cb (void *cls,
     }
     dcc->qs = i + 1;
     rval = dcc->cb (dcc->cb_cls,
-                    serial_id,
                     &dc);
     GNUNET_PQ_cleanup_result (rs);
     if (GNUNET_OK != rval)
@@ -110,12 +116,12 @@ TAH_PG_get_emergency_by_count (
   void *cls,
   int64_t limit,
   uint64_t offset,
-  bool return_suppressed,            // maybe not needed
+  bool return_suppressed,
   TALER_AUDITORDB_EmergenciesByCountCallback cb,
   void *cb_cls)
 {
-  uint64_t plimit = (uint64_t) ((limit < 0) ? -limit : limit);
   struct PostgresClosure *pg = cls;
+  uint64_t plimit = (uint64_t) ((limit < 0) ? -limit : limit);
   struct GNUNET_PQ_QueryParam params[] = {
     GNUNET_PQ_query_param_uint64 (&offset),
     GNUNET_PQ_query_param_bool (return_suppressed),
@@ -140,9 +146,10 @@ TAH_PG_get_emergency_by_count (
            ",start"
            ",deposit_end"
            ",value"
+           ",suppressed"
            " FROM auditor_emergency_by_count"
            " WHERE (row_id < $1)"
-           " AND ($2 OR suppressed is false)"
+           " AND ($2 OR NOT suppressed)"
            " ORDER BY row_id DESC"
            " LIMIT $3"
            );
@@ -157,21 +164,21 @@ TAH_PG_get_emergency_by_count (
            ",start"
            ",deposit_end"
            ",value"
+           ",suppressed"
            " FROM auditor_emergency_by_count"
            " WHERE (row_id > $1)"
-           " AND ($2 OR suppressed is false)"
+           " AND ($2 OR NOT suppressed)"
            " ORDER BY row_id ASC"
            " LIMIT $3"
            );
-  qs = GNUNET_PQ_eval_prepared_multi_select (pg->conn,
-                                             (limit > 0)
-                                             ?
-                                             "auditor_emergency_by_count_get_asc"
-                                             :
-                                             "auditor_emergency_by_count_get_desc",
-                                             params,
-                                             &emergency_by_count_cb,
-                                             &dcc);
+  qs = GNUNET_PQ_eval_prepared_multi_select (
+    pg->conn,
+    (limit > 0)
+    ? "auditor_emergency_by_count_get_asc"
+    : "auditor_emergency_by_count_get_desc",
+    params,
+    &emergency_by_count_cb,
+    &dcc);
   if (qs > 0)
     return dcc.qs;
   GNUNET_break (GNUNET_DB_STATUS_HARD_ERROR != qs);
