@@ -13,16 +13,14 @@
    You should have received a copy of the GNU General Public License along with
    TALER; see the file COPYING.  If not, see <http://www.gnu.org/licenses/>
  */
-
 #include "platform.h"
 #include "taler_error_codes.h"
 #include "taler_dbevents.h"
 #include "taler_pq_lib.h"
 #include "pg_helper.h"
-
-
 #include "pg_get_reserve_balance_insufficient_inconsistency.h"
 
+
 /**
  * Closure for #reserve_balance_insufficient_inconsistency_cb().
  */
@@ -70,18 +68,18 @@ reserve_balance_insufficient_inconsistency_cb (void *cls,
 
   for (unsigned int i = 0; i < num_results; i++)
   {
-    uint64_t serial_id;
-
     struct TALER_AUDITORDB_ReserveBalanceInsufficientInconsistency dc;
-
     struct GNUNET_PQ_ResultSpec rs[] = {
-
-      GNUNET_PQ_result_spec_uint64 ("row_id", &serial_id),
-      GNUNET_PQ_result_spec_auto_from_type ("reserve_pub",  &dc.reserve_pub),
-      GNUNET_PQ_result_spec_bool ("inconsistency_gain", &dc.inconsistency_gain),
+      GNUNET_PQ_result_spec_uint64 ("row_id",
+                                    &dc.row_id),
+      GNUNET_PQ_result_spec_auto_from_type ("reserve_pub",
+                                            &dc.reserve_pub),
+      GNUNET_PQ_result_spec_bool ("inconsistency_gain",
+                                  &dc.inconsistency_gain),
       TALER_PQ_RESULT_SPEC_AMOUNT ("inconsistency_amount",
                                    &dc.inconsistency_amount),
-
+      GNUNET_PQ_result_spec_bool ("suppressed",
+                                  &dc.suppressed),
       GNUNET_PQ_result_spec_end
     };
     enum GNUNET_GenericReturnValue rval;
@@ -95,11 +93,8 @@ reserve_balance_insufficient_inconsistency_cb (void *cls,
       dcc->qs = GNUNET_DB_STATUS_HARD_ERROR;
       return;
     }
-
     dcc->qs = i + 1;
-
     rval = dcc->cb (dcc->cb_cls,
-                    serial_id,
                     &dc);
     GNUNET_PQ_cleanup_result (rs);
     if (GNUNET_OK != rval)
@@ -113,14 +108,12 @@ TAH_PG_get_reserve_balance_insufficient_inconsistency (
   void *cls,
   int64_t limit,
   uint64_t offset,
-  bool return_suppressed,            // maybe not needed
+  bool return_suppressed,
   TALER_AUDITORDB_ReserveBalanceInsufficientInconsistencyCallback cb,
   void *cb_cls)
 {
-
-  uint64_t plimit = (uint64_t) ((limit < 0) ? -limit : limit);
-
   struct PostgresClosure *pg = cls;
+  uint64_t plimit = (uint64_t) ((limit < 0) ? -limit : limit);
   struct GNUNET_PQ_QueryParam params[] = {
     GNUNET_PQ_query_param_uint64 (&offset),
     GNUNET_PQ_query_param_bool (return_suppressed),
@@ -141,9 +134,10 @@ TAH_PG_get_reserve_balance_insufficient_inconsistency (
            ",reserve_pub"
            ",inconsistency_gain"
            ",inconsistency_amount"
+           ",suppressed"
            " FROM auditor_reserve_balance_insufficient_inconsistency"
            " WHERE (row_id < $1)"
-           " AND ($2 OR suppressed is false)"
+           " AND ($2 OR NOT suppressed)"
            " ORDER BY row_id DESC"
            " LIMIT $3"
            );
@@ -154,22 +148,21 @@ TAH_PG_get_reserve_balance_insufficient_inconsistency (
            ",reserve_pub"
            ",inconsistency_gain"
            ",inconsistency_amount"
+           ",suppressed"
            " FROM auditor_reserve_balance_insufficient_inconsistency"
            " WHERE (row_id > $1)"
-           " AND ($2 OR suppressed is false)"
+           " AND ($2 OR NOT suppressed)"
            " ORDER BY row_id ASC"
            " LIMIT $3"
            );
-  qs = GNUNET_PQ_eval_prepared_multi_select (pg->conn,
-                                             (limit > 0) ?
-                                             "auditor_reserve_balance_insufficient_inconsistency_get_asc"
-  :
-                                             "auditor_reserve_balance_insufficient_inconsistency_get_desc",
-                                             params,
-                                             &
-                                             reserve_balance_insufficient_inconsistency_cb,
-                                             &dcc);
-
+  qs = GNUNET_PQ_eval_prepared_multi_select (
+    pg->conn,
+    (limit > 0)
+    ? "auditor_reserve_balance_insufficient_inconsistency_get_asc"
+    : "auditor_reserve_balance_insufficient_inconsistency_get_desc",
+    params,
+    &reserve_balance_insufficient_inconsistency_cb,
+    &dcc);
   if (qs > 0)
     return dcc.qs;
   GNUNET_break (GNUNET_DB_STATUS_HARD_ERROR != qs);
