@@ -30,6 +30,8 @@
  * Obtain all of the historic denomination key revenue
  *
  * @param cls the @e cls of this struct with the plugin-specific state
+ * @param limit return at most this number of results, negative to descend from @a offset
+ * @param offset row from which to return @a limit results
  * @param cb function to call with the results
  * @param cb_cls closure for @a cb
  * @return transaction status code
@@ -37,6 +39,8 @@
 enum GNUNET_DB_QueryStatus
 TAH_PG_select_historic_denom_revenue (
   void *cls,
+  int64_t limit,
+  uint64_t offset,
   TALER_AUDITORDB_HistoricDenominationRevenueDataCallback cb,
   void *cb_cls);
 
