@@ -23,6 +23,8 @@
 #include "taler_pq_lib.h"
 #include <pthread.h>
 #include <libpq-fe.h>
+#include "pg_delete_auditor_closure_lag.h"
+#include "pg_delete_early_aggregation.h"
 #include "pg_delete_generic.h"
 #include "pg_delete_pending_deposit.h"
 #include "pg_delete_purse_info.h"
@@ -42,6 +44,7 @@
 #include "pg_insert_balance.h"
 #include "pg_insert_denomination_balance.h"
 #include "pg_insert_deposit_confirmation.h"
+#include "pg_insert_early_aggregation.h"
 #include "pg_insert_exchange_signkey.h"
 #include "pg_insert_historic_denom_revenue.h"
 #include "pg_insert_historic_reserve_revenue.h"
@@ -481,7 +484,7 @@ postgres_gc (void *cls)
   if (NULL == conn)
     return GNUNET_SYSERR;
   GNUNET_log (GNUNET_ERROR_TYPE_ERROR,
-              "TODO: Auditor GC not implemented (#4960)\n");
+              "FIXME: Auditor GC not implemented (#9433)\n");
   qs = GNUNET_PQ_eval_prepared_non_select (conn,
                                            "gc_auditor",
                                            params_time);
@@ -553,6 +556,8 @@ libtaler_plugin_auditordb_postgres_init (void *cls)
   plugin->delete_wire_out_inconsistency_if_matching
     = &TAH_PG_delete_wire_out_inconsistency_if_matching;
 
+  plugin->delete_auditor_closure_lag
+    = &TAH_PG_delete_auditor_closure_lag;
 
   plugin->update_auditor_progress
     = &TAH_PG_update_auditor_progress;
@@ -695,6 +700,11 @@ libtaler_plugin_auditordb_postgres_init (void *cls)
     &TAH_PG_insert_wire_format_inconsistency;
   plugin->get_wire_format_inconsistency = &TAH_PG_get_wire_format_inconsistency;
 
+  plugin->insert_early_aggregation
+    = &TAH_PG_insert_early_aggregation;
+  plugin->delete_early_aggregation
+    = &TAH_PG_delete_early_aggregation;
+
   plugin->insert_wire_out_inconsistency
     = &TAH_PG_insert_wire_out_inconsistency;
   plugin->get_wire_out_inconsistency
