@@ -347,6 +347,35 @@ run (void *cls)
              );
   }
 
+  {
+    struct TALER_AUDITORDB_ClosureLags cl = {
+      .problem_row_id = 42
+    };
+
+    GNUNET_assert (GNUNET_OK ==
+                   TALER_string_to_amount (CURRENCY ":12.345678",
+                                           &cl.amount));
+    cl.account.full_payto
+      = (char *) "payto://unspec/foo?receiver-name=bar";
+    memset (&cl.wtid,
+            42,
+            sizeof (cl.wtid));
+    cl.deadline = GNUNET_TIME_absolute_get ();
+    FAILIF (GNUNET_DB_STATUS_SUCCESS_NO_RESULTS !=
+            plugin->delete_auditor_closure_lag (plugin->cls,
+                                                &cl.amount,
+                                                &cl.wtid,
+                                                cl.account));
+    FAILIF (GNUNET_DB_STATUS_SUCCESS_ONE_RESULT !=
+            plugin->insert_auditor_closure_lags (plugin->cls,
+                                                 &cl));
+    FAILIF (GNUNET_DB_STATUS_SUCCESS_ONE_RESULT !=
+            plugin->delete_auditor_closure_lag (plugin->cls,
+                                                &cl.amount,
+                                                &cl.wtid,
+                                                cl.account));
+  }
+
   {
     struct TALER_AUDITORDB_DenominationCirculationData dcd;
     struct TALER_AUDITORDB_DenominationCirculationData dcd2;
@@ -419,8 +448,8 @@ run (void *cls)
   FAILIF (0 >=
           plugin->select_historic_denom_revenue (
             plugin->cls,
-            0,
-            1024,
+            1024, /* limit */
+            0, /* offset */
             &select_historic_denom_revenue_result,
             NULL));
   GNUNET_log (GNUNET_ERROR_TYPE_INFO,
@@ -443,8 +472,8 @@ run (void *cls)
   FAILIF (0 >=
           plugin->select_historic_reserve_revenue (
             plugin->cls,
-            0,
-            1024,
+            1024, /* limit */
+            0,    /* offset */
             &select_historic_reserve_revenue_result,
             NULL));
 
