@@ -248,7 +248,8 @@ TALER_FAKEBANK_run_mhd_ (void *cls)
   while (h->mhd_again)
   {
     h->mhd_again = false;
-    MHD_run (h->mhd_bank);
+    GNUNET_assert (MHD_YES ==
+                   MHD_run (h->mhd_bank));
   }
 #ifdef __linux__
   GNUNET_assert (-1 == h->lp_event);
