@@ -216,7 +216,7 @@ credit_history_cb (void *cls,
                  GNUNET_TIME_timestamp2s (cd->execution_date));
         break;
       case TALER_BANK_CT_WAD:
-        GNUNET_break (0); // FIXME
+        GNUNET_break (0); // FIXME-#7271 (support wad payments)
         break;
       }
     }
