@@ -357,20 +357,20 @@ load_offline_key (int do_create)
     test_shutdown ();
     return GNUNET_SYSERR;
   }
-  if (GNUNET_YES !=
-      GNUNET_DISK_file_test (fn))
-    GNUNET_log (GNUNET_ERROR_TYPE_INFO,
-                "Auditor private key `%s' does not exist yet, creating it!\n",
-                fn);
   ret = GNUNET_CRYPTO_eddsa_key_from_file (fn,
                                            do_create,
                                            &auditor_priv.eddsa_priv);
   if (GNUNET_SYSERR == ret)
   {
-    GNUNET_log (GNUNET_ERROR_TYPE_ERROR,
-                "Failed to initialize auditor key from file `%s': %s\n",
-                fn,
-                "could not create file");
+    if (do_create)
+      GNUNET_log (GNUNET_ERROR_TYPE_ERROR,
+                  "Failed to initialize auditor key at `%s': %s\n",
+                  fn,
+                  "could not create file");
+    else
+      GNUNET_log (GNUNET_ERROR_TYPE_ERROR,
+                  "Failed to load auditor key from file `%s': try running `taler-auditor-offline setup'?\n",
+                  fn);
     GNUNET_free (fn);
     test_shutdown ();
     return GNUNET_SYSERR;
@@ -1394,6 +1394,7 @@ run (void *cls,
   kcfg = cfg;
   if (GNUNET_OK !=
       TALER_config_get_currency (kcfg,
+                                 "exchange",
                                  &currency))
   {
     global_ret = EXIT_NOTCONFIGURED;
@@ -1470,21 +1471,13 @@ main (int argc,
   };
   enum GNUNET_GenericReturnValue ret;
 
-  if (GNUNET_OK !=
-      GNUNET_STRINGS_get_utf8_args (argc, argv,
-                                    &argc, &argv))
-    return EXIT_INVALIDARGUMENT;
-  /* force linker to link against libtalerutil; if we do
-     not do this, the linker may "optimize" libtalerutil
-     away and skip #TALER_OS_init(), which we do need */
-  TALER_OS_init ();
   ret = GNUNET_PROGRAM_run (
+    TALER_AUDITOR_project_data (),
     argc, argv,
     "taler-auditor-offline",
     gettext_noop ("Operations for offline signing for a Taler exchange"),
     options,
     &run, NULL);
-  GNUNET_free_nz ((void *) argv);
   if (GNUNET_SYSERR == ret)
     return EXIT_INVALIDARGUMENT;
   if (GNUNET_NO == ret)
