@@ -1,6 +1,6 @@
 /*
   This file is part of TALER
-  Copyright (C) 2016-2024 Taler Systems SA
+  Copyright (C) 2016-2025 Taler Systems SA
 
   TALER is free software; you can redistribute it and/or modify it under the
   terms of the GNU Affero General Public License as published by the Free Software
@@ -1015,10 +1015,12 @@ do_aggregate (struct AggregationUnit *au)
     struct GNUNET_TIME_Timestamp start_date;
     struct GNUNET_TIME_Timestamp end_date;
     struct TALER_MasterSignatureP master_sig;
+    uint64_t rowid;
 
     qs = db_plugin->get_wire_fee (db_plugin->cls,
                                   au->wa->method,
                                   au->execution_time,
+                                  &rowid,
                                   &start_date,
                                   &end_date,
                                   &au->fees,
@@ -1266,40 +1268,6 @@ run_shard (void *cls)
 }
 
 
-/**
- * Function called on transient aggregations matching
- * a particular hash of a payto URI.
- *
- * @param cls
- * @param payto_uri corresponding payto URI
- * @param wtid wire transfer identifier of transient aggregation
- * @param merchant_pub public key of the merchant
- * @param total amount aggregated so far
- * @return true to continue to iterate
- */
-static bool
-handle_transient_cb (
-  void *cls,
-  const struct TALER_FullPayto payto_uri,
-  const struct TALER_WireTransferIdentifierRawP *wtid,
-  const struct TALER_MerchantPublicKeyP *merchant_pub,
-  const struct TALER_Amount *total)
-{
-  struct AggregationUnit *au = cls;
-
-  au->payto_uri.full_payto
-    = GNUNET_strdup (payto_uri.full_payto);
-  TALER_full_payto_hash (payto_uri,
-                         &au->h_full_payto);
-  au->wtid = *wtid;
-  au->merchant_pub = *merchant_pub;
-  au->trans = *total;
-  au->have_transient = true;
-  do_aggregate (au);
-  return false;
-}
-
-
 static void
 drain_kyc_alerts (void *cls)
 {
@@ -1370,12 +1338,13 @@ drain_kyc_alerts (void *cls)
       /* handled below */
       break;
     }
-
-    /* FIXME: should be replaced with a query that has a LIMIT 1... */
-    qs = db_plugin->find_aggregation_transient (db_plugin->cls,
-                                                &au->h_normalized_payto,
-                                                &handle_transient_cb,
-                                                au);
+    qs = db_plugin->find_aggregation_transient (
+      db_plugin->cls,
+      &au->h_normalized_payto,
+      &au->payto_uri,
+      &au->wtid,
+      &au->merchant_pub,
+      &au->trans);
     switch (qs)
     {
     case GNUNET_DB_STATUS_HARD_ERROR:
@@ -1397,8 +1366,11 @@ drain_kyc_alerts (void *cls)
       return;
     case GNUNET_DB_STATUS_SUCCESS_NO_RESULTS:
       continue; /* while (1) */
-    default:
-      /* handle_transient_cb has various continuations... */
+    case GNUNET_DB_STATUS_SUCCESS_ONE_RESULT:
+      TALER_full_payto_hash (au->payto_uri,
+                             &au->h_full_payto);
+      au->have_transient = true;
+      do_aggregate (au);
       return;
     }
     GNUNET_assert (0);
