@@ -2127,10 +2127,17 @@ handle_mhd_request (void *cls,
       return ret;
     }
   }
+  /* FIXME: Why is this handled separately? Fix or justify! */
   if (0 == strncmp (url,
                     "/kyc-upload/",
                     strlen ("/kyc-upload/")))
   {
+    if (0 == strcasecmp (method,
+                         MHD_HTTP_METHOD_OPTIONS))
+    {
+      GNUNET_async_scope_restore (&old_scope);
+      return TALER_MHD_reply_cors_preflight (connection);
+    }
     if (0 != strcasecmp (method,
                          MHD_HTTP_METHOD_POST))
     {
