@@ -220,7 +220,7 @@ find_original_commitment (
     case GNUNET_DB_STATUS_SUCCESS_NO_RESULTS:
       *result = TALER_MHD_reply_with_error (connection,
                                             MHD_HTTP_NOT_FOUND,
-                                            TALER_EC_EXCHANGE_AGE_WITHDRAW_COMMITMENT_UNKNOWN,
+                                            TALER_EC_EXCHANGE_WITHDRAW_COMMITMENT_UNKNOWN,
                                             NULL);
       return GNUNET_SYSERR;
     case GNUNET_DB_STATUS_HARD_ERROR:
@@ -485,7 +485,7 @@ verify_commitment_and_max_age (
     {
       GNUNET_break_op (0);
       *result = TALER_MHD_reply_with_ec (connection,
-                                         TALER_EC_EXCHANGE_AGE_WITHDRAW_REVEAL_INVALID_HASH,
+                                         TALER_EC_EXCHANGE_WITHDRAW_REVEAL_INVALID_HASH,
                                          NULL);
       return GNUNET_SYSERR;
     }
