@@ -178,6 +178,7 @@ TEH_handler_post_aml_decision (
   bool to_investigate;
   struct GNUNET_TIME_Timestamp decision_time;
   const json_t *new_rules;
+  const json_t *events = NULL;
   const json_t *properties = NULL;
   struct TALER_FullPayto payto_uri = {
     .full_payto = NULL
@@ -207,6 +208,10 @@ TEH_handler_post_aml_decision (
       GNUNET_JSON_spec_object_const ("properties",
                                      &properties),
       NULL),
+    GNUNET_JSON_spec_mark_optional (
+      GNUNET_JSON_spec_object_const ("events",
+                                     &events),
+      NULL),
     GNUNET_JSON_spec_bool ("keep_investigating",
                            &to_investigate),
     GNUNET_JSON_spec_fixed_auto ("officer_sig",
@@ -328,11 +333,28 @@ TEH_handler_post_aml_decision (
   }
 
   {
+    size_t num_events = json_array_size (events);
+    const char *sevents[GNUNET_NZL (num_events)];
     enum GNUNET_DB_QueryStatus qs;
     struct GNUNET_TIME_Timestamp last_date;
     bool invalid_officer = true;
     bool unknown_account = false;
 
+    for (size_t i = 0; i<num_events; i++)
+    {
+      sevents[i] = json_string_value (json_array_get (events,
+                                                      i));
+      if (NULL == sevents[i])
+      {
+        GNUNET_break_op (0);
+        ret = TALER_MHD_reply_with_error (
+          connection,
+          MHD_HTTP_BAD_REQUEST,
+          TALER_EC_GENERIC_PARAMETER_MALFORMED,
+          "events");
+        goto done;
+      }
+    }
     /* We keep 'new_measures' around mostly so that
        the auditor can later verify officer_sig */
     qs = TEH_plugin->insert_aml_decision (TEH_plugin->cls,
@@ -348,6 +370,8 @@ TEH_handler_post_aml_decision (
                                           justification,
                                           officer_pub,
                                           &officer_sig,
+                                          num_events,
+                                          sevents,
                                           &invalid_officer,
                                           &unknown_account,
                                           &last_date,
