@@ -40,7 +40,6 @@ add_response_headers (void *cls,
                       struct MHD_Response *response)
 {
   (void) cls;
-  TALER_MHD_add_global_headers (response);
   GNUNET_break (MHD_YES ==
                 MHD_add_response_header (response,
                                          MHD_HTTP_HEADER_CACHE_CONTROL,
@@ -610,6 +609,7 @@ TEH_handler_coins_get (struct TEH_RequestContext *rc,
     enum GNUNET_DB_QueryStatus qs;
 
     qs = TEH_plugin->get_coin_transactions (TEH_plugin->cls,
+                                            true,
                                             coin_pub,
                                             start_off,
                                             etag_in,
@@ -655,9 +655,8 @@ TEH_handler_coins_get (struct TEH_RequestContext *rc,
   if (NULL == tl)
   {
     /* 204: empty history */
-    resp = MHD_create_response_from_buffer (0,
-                                            "",
-                                            MHD_RESPMEM_PERSISTENT);
+    resp = MHD_create_response_from_buffer_static (0,
+                                                   "");
     http_status = MHD_HTTP_NO_CONTENT;
   }
   else
