@@ -611,6 +611,8 @@ handle_aml_fallback_result (
   struct TEH_KycAmlFallback *fb = cls;
   enum GNUNET_DB_QueryStatus qs;
   struct GNUNET_AsyncScopeSave old_scope;
+  json_t *jmeasures = NULL;
+  struct TALER_KYCLOGIC_LegitimizationRuleSet *lrs = NULL;
 
   fb->aprh = NULL;
   GNUNET_async_scope_enter (&fb->scope,
@@ -631,46 +633,72 @@ handle_aml_fallback_result (
       fb->cb (fb->cb_cls,
               false,
               0);
-      TEH_kyc_fallback_cancel (fb);
-      GNUNET_async_scope_restore (&old_scope);
-      return;
+      goto cleanup;
     }
     /* Fallback not allowed on fallback */
     GNUNET_break (0);
     fb->cb (fb->cb_cls,
             false,
             0);
-    TEH_kyc_fallback_cancel (fb);
-    GNUNET_async_scope_restore (&old_scope);
-    return;
+    goto cleanup;
+  }
+
+  if (NULL != apr->details.success.new_measures)
+  {
+    lrs = TALER_KYCLOGIC_rules_parse (apr->details.success.new_rules);
+    GNUNET_assert (NULL != lrs);
+    jmeasures = TALER_KYCLOGIC_get_jmeasures (
+      lrs,
+      apr->details.success.new_measures);
+    GNUNET_assert (NULL != jmeasures);
+  }
+
+  {
+    struct TALER_FullPayto null_payto_uri = { 0 };
+    bool invalid_officer;
+    bool unknown_account;
+    struct GNUNET_TIME_Timestamp last_date;
+    uint64_t legitimization_measure_serial_id;
+
+    qs = TEH_plugin->insert_aml_decision (
+      TEH_plugin->cls,
+      null_payto_uri,
+      &fb->account_id,
+      GNUNET_TIME_timestamp_get (),
+      apr->details.success.expiration_time,
+      apr->details.success.account_properties,
+      apr->details.success.new_rules,
+      apr->details.success.to_investigate,
+      apr->details.success.new_measures,
+      jmeasures,
+      NULL, /* justification */
+      NULL, /* decider_pub */
+      NULL, /* decider_sig */
+      apr->details.success.num_events,
+      apr->details.success.events,
+      &invalid_officer,
+      &unknown_account,
+      &last_date,
+      &legitimization_measure_serial_id);
   }
 
-  qs = TEH_plugin->insert_kyc_measure_result (
-    TEH_plugin->cls,
-    fb->orig_requirement_row,
-    &fb->account_id,
-    apr->details.success.expiration_time,
-    apr->details.success.account_properties,
-    apr->details.success.new_rules,
-    apr->details.success.to_investigate,
-    apr->details.success.num_events,
-    apr->details.success.events);
   if (qs < 0)
   {
     GNUNET_break (0);
     fb->cb (fb->cb_cls,
             false,
             0);
-    GNUNET_async_scope_restore (&old_scope);
-    TEH_kyc_fallback_cancel (fb);
-    return;
+    goto cleanup;
   }
   /* Finally, return result to main handler */
   fb->cb (fb->cb_cls,
           true,
           0);
+cleanup:
   TEH_kyc_fallback_cancel (fb);
   GNUNET_async_scope_restore (&old_scope);
+  TALER_KYCLOGIC_rules_free (lrs);
+  json_decref (jmeasures);
 }
 
 
