@@ -31,70 +31,106 @@
 
 
 /**
- * Function called after the KYC-AML trigger is done.
+ * Function called after a measure has been run.
  *
  * @param cls closure
- * @param http_status final HTTP status to return
- * @param[in] response final HTTP ro return
+ * @param ec error code or 0 on success
+ * @param detail error message or NULL on success / no info
  */
 typedef void
-(*TEH_KycAmlTriggerCallback) (
+(*TEH_KycMeasureRunContextCallback) (
   void *cls,
-  unsigned int http_status,
-  struct MHD_Response *response);
+  enum TALER_ErrorCode ec,
+  const char *detail);
 
 
 /**
  * Handle for an asynchronous operation to finish
  * a KYC process after running the AML trigger.
  */
-struct TEH_KycAmlTrigger;
+struct TEH_KycMeasureRunContext;
 
 
 /**
- * We have finished a KYC process and obtained new
- * @a attributes for a given @a account_id.
- * Check with the KYC-AML trigger to see if we need
- * to initiate an AML process, and store the attributes
- * in the database. Then call @a cb.
+ * Store attributes from the given KYC provider.
+ *
+ * FIXME: Isn't the account_id redundant via the process_row?
  *
- * @param scope the HTTP request logging scope
  * @param process_row legitimization process the data provided is about
- * @param account_id account the webhook was about
- * @param provider_name name of the provider with the logic that was run
+ * @param account_id account the the data provided is about
+ * @param provider_name name of the provider that provided the attributes
  * @param provider_user_id set to user ID at the provider, or NULL if not supported or unknown
  * @param provider_legitimization_id set to legitimization process ID at the provider, or NULL if not supported or unknown
  * @param expiration until when is the KYC check valid
- * @param attributes user attributes returned by the provider
- * @param http_status HTTP status code of @a response
- * @param[in] response to return to the HTTP client
- * @param cb function to call with the result
- * @param cb_cls closure for @a cb
+ * @param new_attributes user attributes returned by the provider
  * @return handle to cancel the operation
  */
-struct TEH_KycAmlTrigger *
-TEH_kyc_finished (
-  const struct GNUNET_AsyncScopeId *scope,
+enum GNUNET_DB_QueryStatus
+TEH_kyc_store_attributes (
   uint64_t process_row,
-  const struct TALER_PaytoHashP *account_id,
+  const struct TALER_NormalizedPaytoHashP *account_id,
   const char *provider_name,
   const char *provider_user_id,
   const char *provider_legitimization_id,
   struct GNUNET_TIME_Absolute expiration,
-  const json_t *attributes,
-  unsigned int http_status,
-  struct MHD_Response *response,
-  TEH_KycAmlTriggerCallback cb,
+  const json_t *new_attributes);
+
+
+/**
+ * Run measure after storing attributes from the given
+ * provider.
+ *
+ * Only works when a process is active.
+ *
+ * @param scope the HTTP request logging scope
+ * @param process_row legitimization process the data provided is about
+ * @param account_id account the the data provided is about
+ * @param cb function to call with the result
+ * @param cb_cls closure for @a cb
+ * @return handle to cancel the operation
+ */
+// FIXME: function should probably be renamed...
+struct TEH_KycMeasureRunContext *
+TEH_kyc_run_measure_for_attributes (
+  const struct GNUNET_AsyncScopeId *scope,
+  uint64_t process_row,
+  const struct TALER_NormalizedPaytoHashP *account_id,
+  TEH_KycMeasureRunContextCallback cb,
   void *cb_cls);
 
 
 /**
- * Cancel KYC finish operation.
+ * Run an measure directly.
+ *
+ * Inserts a legitimization process and measure
+ * into the database before running the measure program.
+ *
+ * After running the measure program, the result is stored
+ * in the DB.
+ *
+ * @param scope the HTTP request logging scope
+ * @param instant_ms instant measure to run
+ * @param account_id account affected by the measure
+ * @param cb function to call with the result
+ * @param cb_cls closure for @a cb
+ * @return handle to cancel the operation
+ */
+struct TEH_KycMeasureRunContext *
+TEH_kyc_run_measure_directly (
+  const struct GNUNET_AsyncScopeId *scope,
+  const struct TALER_KYCLOGIC_Measure *instant_ms,
+  const struct TALER_NormalizedPaytoHashP *account_id,
+  TEH_KycMeasureRunContextCallback cb,
+  void *cb_cls);
+
+
+/**
+ * Cancel running KYC measure.
  *
  * @param[in] kat operation to abort
  */
 void
-TEH_kyc_finished_cancel (struct TEH_KycAmlTrigger *kat);
+TEH_kyc_run_measure_cancel (struct TEH_KycMeasureRunContext *kat);
 
 
 /**
@@ -127,9 +163,6 @@ typedef void
  * @param account_id account to activate fallback for
  * @param orig_requirement_row original requirement
  *    row that now triggered the fallback
- * @param attributes attributes to run with
- * @param aml_history AML history of the account
- * @param kyc_history KYC history of the account
  * @param fallback_measure fallback to activate
  * @param cb callback to call with result
  * @param cb_cls closure for @a cb
@@ -139,12 +172,8 @@ typedef void
 struct TEH_KycAmlFallback *
 TEH_kyc_fallback (
   const struct GNUNET_AsyncScopeId *scope,
-  const struct TALER_PaytoHashP *
-  account_id,
+  const struct TALER_NormalizedPaytoHashP *account_id,
   uint64_t orig_requirement_row,
-  const json_t *attributes,
-  const json_t *aml_history,
-  const json_t *kyc_history,
   const char *fallback_measure,
   TEH_KycAmlFallbackCallback cb,
   void *cb_cls);
@@ -176,7 +205,7 @@ TEH_kyc_fallback_cancel (
 bool
 TEH_kyc_failed (
   uint64_t process_row,
-  const struct TALER_PaytoHashP *account_id,
+  const struct TALER_NormalizedPaytoHashP *account_id,
   const char *provider_name,
   const char *provider_user_id,
   const char *provider_legitimization_id,
@@ -194,6 +223,12 @@ struct TEH_LegitimizationCheckResult
    */
   struct TALER_EXCHANGEDB_KycStatus kyc;
 
+  /**
+   * Last reserve public key of a wire transfer from
+   * the account to the exchange.
+   */
+  union TALER_AccountPublicKeyP reserve_pub;
+
   /**
    * Smallest amount (over any timeframe) that may
    * require additional KYC checks (if @a kyc.ok).
@@ -206,11 +241,6 @@ struct TEH_LegitimizationCheckResult
    */
   struct GNUNET_TIME_Timestamp expiration_date;
 
-  /**
-   * HTTP status code for @a response, or 0
-   */
-  unsigned int http_status;
-
   /**
    * Response to return. Note that the response must
    * be queued or destroyed by the callee.  NULL
@@ -218,6 +248,24 @@ struct TEH_LegitimizationCheckResult
    * a handler-specific result.
    */
   struct MHD_Response *response;
+
+  /**
+   * HTTP status code for @a response, or 0
+   */
+  unsigned int http_status;
+
+  /**
+   * True if @e reserve_pub is set.
+   */
+  bool have_reserve_pub;
+
+  /**
+   * Set to true if the merchant public key does not
+   * match the public key we have on file for this
+   * target account (and thus a new KYC AUTH is
+   * required).
+   */
+  bool bad_kyc_auth;
 };
 
 
@@ -239,6 +287,9 @@ typedef void
 struct TEH_LegitimizationCheckHandle;
 
 
+/* FIXME: add another variation of this API with a
+   NormalizedPayto payto_uri, as we currently 'fake'
+   a full payto in 3 places related to wallets! */
 /**
  * Do legitimization check.
  *
@@ -258,8 +309,8 @@ struct TEH_LegitimizationCheckHandle *
 TEH_legitimization_check (
   const struct GNUNET_AsyncScopeId *scope,
   enum TALER_KYCLOGIC_KycTriggerEvent et,
-  const char *payto_uri,
-  const struct TALER_PaytoHashP *h_payto,
+  const struct TALER_FullPayto payto_uri,
+  const struct TALER_NormalizedPaytoHashP *h_payto,
   const union TALER_AccountPublicKeyP *account_pub,
   TALER_KYCLOGIC_KycAmountIterator ai,
   void *ai_cls,
@@ -267,6 +318,36 @@ TEH_legitimization_check (
   void *result_cb_cls);
 
 
+/**
+ * Do legitimization check and enforce that the current
+ * public key associated with the account is the given
+ * merchant public key.
+ *
+ * @param scope scope for logging
+ * @param et type of event we are checking
+ * @param payto_uri account we are checking for
+ * @param h_payto hash of @a payto_uri
+ * @param merchant_pub public key that must match the
+ *    KYC authorization
+ * @param ai callback to get amounts involved historically
+ * @param ai_cls closure for @a ai
+ * @param result_cb function to call with the result
+ * @param result_cb_cls closure for @a result_cb
+ * @return handle for the operation
+ */
+struct TEH_LegitimizationCheckHandle *
+TEH_legitimization_check2 (
+  const struct GNUNET_AsyncScopeId *scope,
+  enum TALER_KYCLOGIC_KycTriggerEvent et,
+  const struct TALER_FullPayto payto_uri,
+  const struct TALER_NormalizedPaytoHashP *h_payto,
+  const struct TALER_MerchantPublicKeyP *merchant_pub,
+  TALER_KYCLOGIC_KycAmountIterator ai,
+  void *ai_cls,
+  TEH_LegitimizationCheckCallback result_cb,
+  void *result_cb_cls);
+
+
 /**
  * Cancel legitimization check.
  *
