@@ -351,7 +351,10 @@ aml_trigger_callback (
   {
     uc->response_code = TALER_ErrorCode_get_http_status (ec);
     if (0 == uc->response_code)
+    {
+      GNUNET_break (0);
       uc->response_code = MHD_HTTP_INTERNAL_SERVER_ERROR;
+    }
     GNUNET_assert (uc->response_code != UINT_MAX);
     uc->response = TALER_MHD_make_error (
       ec,
@@ -364,8 +367,8 @@ aml_trigger_callback (
       0,
       ""
       );
+    TALER_MHD_add_global_headers (uc->response);
   }
-  TALER_MHD_add_global_headers (uc->response);
 
   MHD_resume_connection (uc->rc->connection);
   GNUNET_CONTAINER_DLL_remove (uc_head,
@@ -479,6 +482,7 @@ TEH_handler_kyc_upload (
     size_t enc_attributes_len;
     void *enc_attributes;
     const char *error_message;
+    char *form_name;
     enum TALER_ErrorCode ec;
 
     qs = TEH_plugin->lookup_completed_legitimization (
@@ -562,6 +566,7 @@ TEH_handler_kyc_upload (
     ec = TALER_KYCLOGIC_check_form (jmeasures,
                                     uc->measure_index,
                                     uc->result,
+                                    &form_name,
                                     &error_message);
     if (TALER_EC_NONE != ec)
     {
@@ -580,13 +585,14 @@ TEH_handler_kyc_upload (
       &h_payto,
       uc->measure_index,
       uc->legitimization_measure_serial_id,
-      "FORM", /* FIXME: get specific form name in DB interaction above! */
+      form_name,
       NULL,     /* provider account ID */
       NULL,     /* provider legi ID */
       &legi_process_row);
     if (qs <= 0)
     {
       GNUNET_break (0);
+      GNUNET_free (form_name);
       return TALER_MHD_reply_with_error (
         rc->connection,
         MHD_HTTP_INTERNAL_SERVER_ERROR,
@@ -596,11 +602,12 @@ TEH_handler_kyc_upload (
     qs = TEH_kyc_store_attributes (
       legi_process_row,
       &h_payto,
-      "FORM", /* FIXME: get specific form name in DB interaction above! */
+      form_name,
       NULL /* provider account */,
       NULL /* provider legi ID */,
       GNUNET_TIME_UNIT_FOREVER_ABS, /* expiration time */
       uc->result);
+    GNUNET_free (form_name);
     if (0 >= qs)
     {
       GNUNET_break (0);
