@@ -259,7 +259,7 @@ reply_merge_success (const struct PurseMergeContext *pmc)
   }
   else
   {
-#if WAD_NOT_IMPLEMENTED
+#if WAD_NOT_IMPLEMENTED /* #7271 */
     /* FIXME: figure out partner, lookup wad fee by partner! #7271 */
     if (0 >
         TALER_amount_subtract (&merge_amount,
