@@ -542,6 +542,7 @@ get_transfer_deposits (void *cls,
   }
   {
     char *wire_method;
+    uint64_t rowid;
 
     wire_method = TALER_payto_get_method (ctx->payto_uri.full_payto);
     if (NULL == wire_method)
@@ -556,6 +557,7 @@ get_transfer_deposits (void *cls,
     qs = TEH_plugin->get_wire_fee (TEH_plugin->cls,
                                    wire_method,
                                    ctx->exec_time,
+                                   &rowid,
                                    &wire_fee_start_date,
                                    &wire_fee_end_date,
                                    &ctx->fees,
