@@ -340,21 +340,21 @@ _Static_assert (
  * and optionally set the given field (with an optionally given value).
  */
 #define SET_ERROR(wc, ec) \
-        do \
-        { (wc)->error.code = (ec); \
-          (wc)->phase = PHASE_GENERATE_REPLY_ERROR; } while (0)
+  do \
+  { (wc)->error.code = (ec); \
+    (wc)->phase = PHASE_GENERATE_REPLY_ERROR; } while (0)
 
 #define SET_ERROR_WITH_FIELD(wc, ec, field) \
-        do \
-        { (wc)->error.code = (ec); \
-          (wc)->error.details.field = (field); \
-          (wc)->phase = PHASE_GENERATE_REPLY_ERROR; } while (0)
+  do \
+  { (wc)->error.code = (ec); \
+    (wc)->error.details.field = (field); \
+    (wc)->phase = PHASE_GENERATE_REPLY_ERROR; } while (0)
 
 #define SET_ERROR_WITH_DETAIL(wc, ec, field, value) \
-        do \
-        { (wc)->error.code = (ec); \
-          (wc)->error.details.field = (value); \
-          (wc)->phase = PHASE_GENERATE_REPLY_ERROR; } while (0)
+  do \
+  { (wc)->error.code = (ec); \
+    (wc)->error.details.field = (value); \
+    (wc)->phase = PHASE_GENERATE_REPLY_ERROR; } while (0)
 
 
 /**
@@ -1888,7 +1888,7 @@ phase_generate_reply_error (
                    wc->rc->connection,
                    MHD_HTTP_CONFLICT,
                    TALER_MHD_PACK_EC (
-                     TALER_EC_EXCHANGE_AGE_WITHDRAW_MAXIMUM_AGE_TOO_LARGE),
+                     TALER_EC_EXCHANGE_WITHDRAW_MAXIMUM_AGE_TOO_LARGE),
                    GNUNET_JSON_pack_uint64 (
                      "allowed_maximum_age",
                      wc->error.details.age.max),
@@ -1908,7 +1908,7 @@ phase_generate_reply_error (
     finish_loop (wc,
                  TEH_RESPONSE_reply_reserve_insufficient_balance (
                    wc->rc->connection,
-                   TALER_EC_EXCHANGE_AGE_WITHDRAW_INSUFFICIENT_FUNDS,
+                   TALER_EC_EXCHANGE_WITHDRAW_INSUFFICIENT_FUNDS,
                    &wc->error.details.reserve_balance,
                    &wc->typ.age.commitment.amount_with_fee,
                    &wc->reserve_pub));
@@ -1919,7 +1919,7 @@ phase_generate_reply_error (
                  TALER_MHD_reply_with_error (
                    wc->rc->connection,
                    MHD_HTTP_BAD_REQUEST,
-                   TALER_EC_EXCHANGE_AGE_WITHDRAW_AMOUNT_OVERFLOW,
+                   TALER_EC_EXCHANGE_WITHDRAW_AMOUNT_OVERFLOW,
                    wc->error.details.which));
     break;
 
@@ -1949,7 +1949,7 @@ phase_generate_reply_error (
                    TALER_MHD_reply_with_error (
                      wc->rc->connection,
                      MHD_HTTP_CONFLICT,
-                     TALER_EC_EXCHANGE_WITHDRAW_BATCH_IDEMPOTENT_PLANCHET,
+                     TALER_EC_EXCHANGE_WITHDRAW_IDEMPOTENT_PLANCHET,
                      NULL));
       break;
     }
