@@ -768,7 +768,7 @@ select_shard (void *cls)
   {
   case GNUNET_DB_STATUS_HARD_ERROR:
     GNUNET_log (GNUNET_ERROR_TYPE_ERROR,
-                "Failed to obtain starting point for montoring from database!\n");
+                "Failed to obtain starting point for monitoring from database!\n");
     global_ret = EXIT_FAILURE;
     GNUNET_SCHEDULER_shutdown ();
     return;
