@@ -32,7 +32,7 @@ BEGIN
   );
 
   PERFORM comment_partitioned_column(
-     'signature by the merchant over the contract terms, of purpuse TALER_SIGNATURE_MERCHANT_CONTRACT'
+     'signature by the merchant over the contract terms, of purpose TALER_SIGNATURE_MERCHANT_CONTRACT'
     ,'merchant_sig'
     ,'batch_deposits'
     ,partition_suffix
