@@ -17,9 +17,22 @@
 -- Everything in one big transaction
 BEGIN;
 
+WITH xpatches AS (
+  SELECT patch_name
+  FROM _v.patches
+  WHERE starts_with(patch_name,'exchange-')
+)
+  SELECT _v.unregister_patch(xpatches.patch_name)
+  FROM xpatches;
 
-SELECT _v.unregister_patch('exchange-0001');
-SELECT _v.unregister_patch('exchange-0002');
+
+WITH xpatches AS (
+  SELECT patch_name
+  FROM _v.patches
+  WHERE starts_with(patch_name,'auditor-triggers-')
+)
+  SELECT _v.unregister_patch(xpatches.patch_name)
+  FROM xpatches;
 
 DROP SCHEMA exchange CASCADE;
 
