@@ -26,10 +26,11 @@ CREATE FUNCTION exchange_do_insert_aml_decision(
   IN in_to_investigate BOOLEAN,
   IN in_new_measure_name TEXT, -- can be NULL
   IN in_jmeasures TEXT, -- can be NULL
-  IN in_justification TEXT,
-  IN in_decider_pub BYTEA,
-  IN in_decider_sig BYTEA,
+  IN in_justification TEXT, -- can be NULL
+  IN in_decider_pub BYTEA, -- can be NULL
+  IN in_decider_sig BYTEA, -- can be NULL
   IN in_notify_s TEXT,
+  IN ina_events TEXT[],
   OUT out_invalid_officer BOOLEAN,
   OUT out_account_unknown BOOLEAN,
   OUT out_last_date INT8,
@@ -39,23 +40,33 @@ AS $$
 DECLARE
   my_outcome_serial_id INT8;
   my_access_token BYTEA;
+  my_i INT4;
+  ini_event TEXT;
 BEGIN
 
 out_account_unknown=FALSE;
 out_legitimization_measure_serial_id=0;
 
--- Check officer is eligible to make decisions.
-PERFORM
-  FROM aml_staff
-  WHERE decider_pub=in_decider_pub
-    AND is_active
-    AND NOT read_only;
-IF NOT FOUND
+IF in_decider_pub IS NOT NULL
 THEN
-  out_invalid_officer=TRUE;
-  out_last_date=0;
-  RETURN;
+  IF in_justification IS NULL OR in_decider_sig IS NULL
+  THEN
+    RAISE EXCEPTION 'Got in_decider_sig without justification or signature.';
+  END IF;
+  -- Check officer is eligible to make decisions.
+  PERFORM
+    FROM aml_staff
+    WHERE decider_pub=in_decider_pub
+      AND is_active
+      AND NOT read_only;
+  IF NOT FOUND
+  THEN
+    out_invalid_officer=TRUE;
+    out_last_date=0;
+    RETURN;
+  END IF;
 END IF;
+
 out_invalid_officer=FALSE;
 
 -- Check no more recent decision exists.
@@ -68,9 +79,9 @@ SELECT decision_time
 
 IF FOUND
 THEN
-  IF out_last_date > in_decision_time
+  IF in_decider_pub IS NOT NULL AND out_last_date > in_decision_time
   THEN
-    -- Refuse to insert older decision.
+    -- Refuse to insert older decision for officer decisions.
     RETURN;
   END IF;
   UPDATE legitimization_outcomes
@@ -177,20 +188,34 @@ INSERT INTO legitimization_outcomes
   INTO
     my_outcome_serial_id;
 
-
-INSERT INTO aml_history
-  (h_payto
-  ,outcome_serial_id
-  ,justification
-  ,decider_pub
-  ,decider_sig
-  ) VALUES
-  (in_h_normalized_payto
-  ,my_outcome_serial_id
-  ,in_justification
-  ,in_decider_pub
-  ,in_decider_sig
+IF in_decider_pub IS NOT NULL
+THEN
+  INSERT INTO aml_history
+    (h_payto
+    ,outcome_serial_id
+    ,justification
+    ,decider_pub
+    ,decider_sig
+    ) VALUES
+    (in_h_normalized_payto
+    ,my_outcome_serial_id
+    ,in_justification
+    ,in_decider_pub
+    ,in_decider_sig
   );
+END IF;
+
+-- Trigger events
+FOR i IN 1..COALESCE(array_length(ina_events,1),0)
+LOOP
+  ini_event = ina_events[i];
+  INSERT INTO kyc_events
+    (event_timestamp
+    ,event_type)
+    VALUES
+    (in_decision_time
+    ,ini_event);
+END LOOP;
 
 -- wake up taler-exchange-aggregator
 INSERT INTO kyc_alerts
@@ -208,5 +233,5 @@ EXECUTE FORMAT (
 END $$;
 
 
-COMMENT ON FUNCTION exchange_do_insert_aml_decision(TEXT, BYTEA, BYTEA, INT8, INT8, TEXT, TEXT, BOOLEAN, TEXT, TEXT, TEXT, BYTEA, BYTEA, TEXT)
+COMMENT ON FUNCTION exchange_do_insert_aml_decision(TEXT, BYTEA, BYTEA, INT8, INT8, TEXT, TEXT, BOOLEAN, TEXT, TEXT, TEXT, BYTEA, BYTEA, TEXT, TEXT[])
   IS 'Checks whether the AML officer is eligible to make AML decisions and if so inserts the decision into the table';
