@@ -40,6 +40,18 @@ TALER_EXCHANGEDB_persist_aml_program_result (
   const struct TALER_KYCLOGIC_AmlProgramResult *apr)
 {
   enum GNUNET_DB_QueryStatus qs;
+  json_t *jmeasures = NULL;
+  struct TALER_KYCLOGIC_LegitimizationRuleSet *lrs = NULL;
+
+  if (NULL != apr->details.success.new_measures)
+  {
+    lrs = TALER_KYCLOGIC_rules_parse (apr->details.success.new_rules);
+    GNUNET_assert (NULL != lrs);
+    jmeasures = TALER_KYCLOGIC_get_jmeasures (
+      lrs,
+      apr->details.success.new_measures);
+    GNUNET_assert (NULL != jmeasures);
+  }
 
   qs = plugin->clear_aml_lock (
     plugin->cls,
@@ -54,23 +66,45 @@ TALER_EXCHANGEDB_persist_aml_program_result (
       apr->details.failure.error_message,
       apr->details.failure.ec);
     GNUNET_break (qs > 0);
-    return qs;
+    goto cleanup;
   case TALER_KYCLOGIC_AMLR_SUCCESS:
-    qs = plugin->insert_kyc_measure_result (
-      plugin->cls,
-      process_row,
-      account_id,
-      apr->details.success.expiration_time,
-      apr->details.success.account_properties,
-      apr->details.success.new_rules,
-      apr->details.success.to_investigate,
-      apr->details.success.num_events,
-      apr->details.success.events);
-    GNUNET_break (qs > 0);
-    return qs;
+    {
+      struct TALER_FullPayto null_payto_uri = { 0 };
+      bool invalid_officer;
+      bool unknown_account;
+      struct GNUNET_TIME_Timestamp last_date;
+      uint64_t legitimization_measure_serial_id;
+
+      qs = plugin->insert_aml_decision (
+        plugin->cls,
+        null_payto_uri,
+        account_id,
+        GNUNET_TIME_timestamp_get (),
+        apr->details.success.expiration_time,
+        apr->details.success.account_properties,
+        apr->details.success.new_rules,
+        apr->details.success.to_investigate,
+        apr->details.success.new_measures,
+        jmeasures,
+        NULL, /* justification */
+        NULL, /* decider_pub */
+        NULL, /* decider_sig */
+        apr->details.success.num_events,
+        apr->details.success.events,
+        &invalid_officer,
+        &unknown_account,
+        &last_date,
+        &legitimization_measure_serial_id);
+      GNUNET_break (qs > 0);
+      goto cleanup;
+    }
   }
-  GNUNET_assert (0);
-  return GNUNET_DB_STATUS_HARD_ERROR;
+  GNUNET_break (0);
+  qs = GNUNET_DB_STATUS_HARD_ERROR;
+cleanup:
+  TALER_KYCLOGIC_rules_free (lrs);
+  json_decref (jmeasures);
+  return qs;
 }
 
 
