@@ -1,6 +1,6 @@
 /*
    This file is part of TALER
-   Copyright (C) 2022 Taler Systems SA
+   Copyright (C) 2022, 2025 Taler Systems SA
 
    TALER is free software; you can redistribute it and/or modify it under the
    terms of the GNU General Public License as published by the Free Software
@@ -29,15 +29,19 @@
  *
  * @param cls the @e cls of this struct with the plugin-specific state
  * @param h_payto destination of the wire transfer
- * @param cb function to call on each matching entry
- * @param cb_cls closure for @a cb
+ * @param[out] payto_uri corresponding payto URI, to be freed by caller
+ * @param[out] wtid wire transfer identifier of transient aggregation
+ * @param[out] merchant_pub public key of the merchant
+ * @param[out] total amount aggregated so far
  * @return transaction status
  */
 enum GNUNET_DB_QueryStatus
 TEH_PG_find_aggregation_transient (
   void *cls,
   const struct TALER_NormalizedPaytoHashP *h_payto,
-  TALER_EXCHANGEDB_TransientAggregationCallback cb,
-  void *cb_cls);
+  struct TALER_FullPayto *payto_uri,
+  struct TALER_WireTransferIdentifierRawP *wtid,
+  struct TALER_MerchantPublicKeyP *merchant_pub,
+  struct TALER_Amount *total);
 
 #endif
