@@ -716,11 +716,11 @@ TEH_PG_get_reserve_history (
   PREPARE (pg,
            "get_reserve_history_etag",
            "SELECT"
-           " hist.reserve_history_serial_id"
+           " his.reserve_history_serial_id"
            ",r.current_balance"
-           " FROM reserve_history hist"
+           " FROM reserve_history his"
            " JOIN reserves r USING (reserve_pub)"
-           " WHERE hist.reserve_pub=$1"
+           " WHERE his.reserve_pub=$1"
            " ORDER BY reserve_history_serial_id DESC"
            " LIMIT 1;");
   PREPARE (pg,
