@@ -26,13 +26,15 @@
 #include "pg_helper.h"
 
 enum GNUNET_DB_QueryStatus
-TEH_PG_get_wire_fee (void *cls,
-                     const char *type,
-                     struct GNUNET_TIME_Timestamp date,
-                     struct GNUNET_TIME_Timestamp *start_date,
-                     struct GNUNET_TIME_Timestamp *end_date,
-                     struct TALER_WireFeeSet *fees,
-                     struct TALER_MasterSignatureP *master_sig)
+TEH_PG_get_wire_fee (
+  void *cls,
+  const char *type,
+  struct GNUNET_TIME_Timestamp date,
+  uint64_t *rowid,
+  struct GNUNET_TIME_Timestamp *start_date,
+  struct GNUNET_TIME_Timestamp *end_date,
+  struct TALER_WireFeeSet *fees,
+  struct TALER_MasterSignatureP *master_sig)
 {
   struct PostgresClosure *pg = cls;
   struct GNUNET_PQ_QueryParam params[] = {
@@ -41,6 +43,8 @@ TEH_PG_get_wire_fee (void *cls,
     GNUNET_PQ_query_param_end
   };
   struct GNUNET_PQ_ResultSpec rs[] = {
+    GNUNET_PQ_result_spec_uint64 ("wire_fee_serial",
+                                  rowid),
     GNUNET_PQ_result_spec_timestamp ("start_date",
                                      start_date),
     GNUNET_PQ_result_spec_timestamp ("end_date",
@@ -56,8 +60,9 @@ TEH_PG_get_wire_fee (void *cls,
 
   PREPARE (pg,
            "get_wire_fee",
-           "SELECT "
-           " start_date"
+           "SELECT"
+           " wire_fee_serial"
+           ",start_date"
            ",end_date"
            ",wire_fee"
            ",closing_fee"
