@@ -42,6 +42,8 @@ TEH_PG_insert_aml_decision (
   const char *justification,
   const struct TALER_AmlOfficerPublicKeyP *decider_pub,
   const struct TALER_AmlOfficerSignatureP *decider_sig,
+  size_t num_events,
+  const char *events[static num_events],
   bool *invalid_officer,
   bool *unknown_account,
   struct GNUNET_TIME_Timestamp *last_date,
@@ -77,10 +79,19 @@ TEH_PG_insert_aml_decision (
     NULL != jmeasures
       ? TALER_PQ_query_param_json (jmeasures)
       : GNUNET_PQ_query_param_null (),
-    GNUNET_PQ_query_param_string (justification),
-    GNUNET_PQ_query_param_auto_from_type (decider_pub),
-    GNUNET_PQ_query_param_auto_from_type (decider_sig),
+    NULL != justification
+      ? GNUNET_PQ_query_param_string (justification)
+      : GNUNET_PQ_query_param_null (),
+    NULL != decider_pub
+      ? GNUNET_PQ_query_param_auto_from_type (decider_pub)
+      : GNUNET_PQ_query_param_null (),
+    NULL != decider_sig
+      ? GNUNET_PQ_query_param_auto_from_type (decider_sig)
+      : GNUNET_PQ_query_param_null (),
     GNUNET_PQ_query_param_string (notify_s),
+    GNUNET_PQ_query_param_array_ptrs_string (num_events,
+                                             events,
+                                             pg->conn),
     GNUNET_PQ_query_param_end
   };
   struct GNUNET_PQ_ResultSpec rs[] = {
@@ -96,6 +107,13 @@ TEH_PG_insert_aml_decision (
   };
   enum GNUNET_DB_QueryStatus qs;
 
+  GNUNET_assert ( ( (NULL == decider_pub) &&
+                    (NULL == decider_sig) &&
+                    (NULL == justification) ) ||
+                  ( (NULL != decider_pub) &&
+                    (NULL != decider_sig) &&
+                    (NULL != justification) ) );
+
   if (NULL != payto_uri.full_payto)
     TALER_full_payto_hash (payto_uri,
                            &h_full_payto);
@@ -107,11 +125,12 @@ TEH_PG_insert_aml_decision (
            ",out_last_date"
            ",out_legitimization_measure_serial_id"
            " FROM exchange_do_insert_aml_decision"
-           "($1, $2, $3, $4, $5, $6, $7, $8, $9, $10, $11, $12, $13, $14);");
+           "($1,$2,$3,$4,$5,$6,$7,$8,$9,$10,$11,$12,$13,$14,$15);");
   qs = GNUNET_PQ_eval_prepared_singleton_select (pg->conn,
                                                  "do_insert_aml_decision",
                                                  params,
                                                  rs);
+  GNUNET_PQ_cleanup_query_params_closures (params);
   GNUNET_free (notify_s);
   GNUNET_PQ_event_do_poll (pg->conn);
   return qs;
