@@ -45,6 +45,8 @@
  * @param justification human-readable text justifying the decision
  * @param decider_pub public key of the staff member
  * @param decider_sig signature of the staff member
+ * @param num_events length of the @a events array
+ * @param events array of events to trigger
  * @param[out] invalid_officer set to TRUE if @a decider_pub is not allowed to make decisions right now
  * @param[out] unknown_account set to TRUE if @a h_payto does not refer to a known account and @a jmeasures was given
  * @param[out] last_date set to the previous decision time;
@@ -68,6 +70,8 @@ TEH_PG_insert_aml_decision (
   const char *justification,
   const struct TALER_AmlOfficerPublicKeyP *decider_pub,
   const struct TALER_AmlOfficerSignatureP *decider_sig,
+  size_t num_events,
+  const char *events[static num_events],
   bool *invalid_officer,
   bool *unknown_account,
   struct GNUNET_TIME_Timestamp *last_date,
