@@ -2260,9 +2260,9 @@ irbt_cb_table_purse_deletion (struct PostgresClosure *pg,
  * @param td record to insert
  */
 static enum GNUNET_DB_QueryStatus
-irbt_cb_table_age_withdraw (struct PostgresClosure *pg,
-                            const struct
-                            TALER_EXCHANGEDB_TableData *td)
+irbt_cb_table_age_withdraw (
+  struct PostgresClosure *pg,
+  const struct TALER_EXCHANGEDB_TableData *td)
 {
   struct GNUNET_PQ_QueryParam params[] = {
     GNUNET_PQ_query_param_uint64 (&td->serial),
@@ -2279,7 +2279,7 @@ irbt_cb_table_age_withdraw (struct PostgresClosure *pg,
       &td->details.age_withdraw.reserve_sig),
     GNUNET_PQ_query_param_uint32 (
       &td->details.age_withdraw.noreveal_index),
-    /* TODO: other fields, too! */
+    /* FIXME[oec]: other fields, too! */
     GNUNET_PQ_query_param_end
   };
 
