@@ -114,7 +114,6 @@
 #include "pg_insert_drain_profit.h"
 #include "pg_insert_global_fee.h"
 #include "pg_insert_kyc_failure.h"
-#include "pg_insert_kyc_measure_result.h"
 #include "pg_insert_kyc_requirement_process.h"
 #include "pg_insert_partner.h"
 #include "pg_insert_purse_request.h"
@@ -123,6 +122,7 @@
 #include "pg_insert_refund.h"
 #include "pg_insert_reserve_closed.h"
 #include "pg_insert_reserve_open_deposit.h"
+#include "pg_insert_sanction_list_hit.h"
 #include "pg_insert_signkey_revocation.h"
 #include "pg_insert_successor_measure.h"
 #include "pg_insert_wire.h"
@@ -174,7 +174,9 @@
 #include "pg_select_aggregation_amounts_for_kyc_check.h"
 #include "pg_select_aggregation_transient.h"
 #include "pg_select_aggregations_above_serial.h"
+#include "pg_select_all_kyc_attributes.h"
 #include "pg_select_all_purse_decisions_above_serial_id.h"
+#include "pg_select_all_purse_deletions_above_serial_id.h"
 #include "pg_select_aml_attributes.h"
 #include "pg_select_aml_decisions.h"
 #include "pg_select_aml_measures.h"
@@ -414,6 +416,8 @@ libtaler_plugin_exchangedb_postgres_init (void *cls)
     = &TEH_PG_select_account_merges_above_serial_id;
   plugin->select_all_purse_decisions_above_serial_id
     = &TEH_PG_select_all_purse_decisions_above_serial_id;
+  plugin->select_all_purse_deletions_above_serial_id
+    = &TEH_PG_select_all_purse_deletions_above_serial_id;
   plugin->select_purse
     = &TEH_PG_select_purse;
   plugin->select_purse_deposits_above_serial_id
@@ -718,6 +722,10 @@ libtaler_plugin_exchangedb_postgres_init (void *cls)
     = &TEH_PG_lookup_signing_key;
   plugin->lookup_h_payto_by_access_token
     = &TEH_PG_lookup_h_payto_by_access_token;
+  plugin->insert_sanction_list_hit
+    = &TEH_PG_insert_sanction_list_hit;
+  plugin->select_all_kyc_attributes
+    = &TEH_PG_select_all_kyc_attributes;
   plugin->begin_shard
     = &TEH_PG_begin_shard;
   plugin->abort_shard
@@ -742,8 +750,6 @@ libtaler_plugin_exchangedb_postgres_init (void *cls)
     = &TEH_PG_set_purse_balance;
   plugin->get_pending_kyc_requirement_process
     = &TEH_PG_get_pending_kyc_requirement_process;
-  plugin->insert_kyc_measure_result
-    = &TEH_PG_insert_kyc_measure_result;
   plugin->select_kyc_attributes
     = &TEH_PG_select_kyc_attributes;
   plugin->insert_aml_officer
