@@ -2459,10 +2459,11 @@ CREATE FUNCTION exchange_do_insert_aml_decision(
   IN in_to_investigate BOOLEAN,
   IN in_new_measure_name TEXT, 
   IN in_jmeasures TEXT, 
-  IN in_justification TEXT,
-  IN in_decider_pub BYTEA,
-  IN in_decider_sig BYTEA,
+  IN in_justification TEXT, 
+  IN in_decider_pub BYTEA, 
+  IN in_decider_sig BYTEA, 
   IN in_notify_s TEXT,
+  IN ina_events TEXT[],
   OUT out_invalid_officer BOOLEAN,
   OUT out_account_unknown BOOLEAN,
   OUT out_last_date INT8,
@@ -2472,19 +2473,28 @@ AS $$
 DECLARE
   my_outcome_serial_id INT8;
   my_access_token BYTEA;
+  my_i INT4;
+  ini_event TEXT;
 BEGIN
 out_account_unknown=FALSE;
 out_legitimization_measure_serial_id=0;
-PERFORM
-  FROM aml_staff
-  WHERE decider_pub=in_decider_pub
-    AND is_active
-    AND NOT read_only;
-IF NOT FOUND
+IF in_decider_pub IS NOT NULL
 THEN
-  out_invalid_officer=TRUE;
-  out_last_date=0;
-  RETURN;
+  IF in_justification IS NULL OR in_decider_sig IS NULL
+  THEN
+    RAISE EXCEPTION 'Got in_decider_sig without justification or signature.';
+  END IF;
+  PERFORM
+    FROM aml_staff
+    WHERE decider_pub=in_decider_pub
+      AND is_active
+      AND NOT read_only;
+  IF NOT FOUND
+  THEN
+    out_invalid_officer=TRUE;
+    out_last_date=0;
+    RETURN;
+  END IF;
 END IF;
 out_invalid_officer=FALSE;
 SELECT decision_time
@@ -2495,7 +2505,7 @@ SELECT decision_time
  ORDER BY decision_time DESC, outcome_serial_id DESC;
 IF FOUND
 THEN
-  IF out_last_date > in_decision_time
+  IF in_decider_pub IS NOT NULL AND out_last_date > in_decision_time
   THEN
     RETURN;
   END IF;
@@ -2585,19 +2595,32 @@ INSERT INTO legitimization_outcomes
     outcome_serial_id
   INTO
     my_outcome_serial_id;
-INSERT INTO aml_history
-  (h_payto
-  ,outcome_serial_id
-  ,justification
-  ,decider_pub
-  ,decider_sig
-  ) VALUES
-  (in_h_normalized_payto
-  ,my_outcome_serial_id
-  ,in_justification
-  ,in_decider_pub
-  ,in_decider_sig
+IF in_decider_pub IS NOT NULL
+THEN
+  INSERT INTO aml_history
+    (h_payto
+    ,outcome_serial_id
+    ,justification
+    ,decider_pub
+    ,decider_sig
+    ) VALUES
+    (in_h_normalized_payto
+    ,my_outcome_serial_id
+    ,in_justification
+    ,in_decider_pub
+    ,in_decider_sig
   );
+END IF;
+FOR i IN 1..COALESCE(array_length(ina_events,1),0)
+LOOP
+  ini_event = ina_events[i];
+  INSERT INTO kyc_events
+    (event_timestamp
+    ,event_type)
+    VALUES
+    (in_decision_time
+    ,ini_event);
+END LOOP;
 INSERT INTO kyc_alerts
   (h_payto
   ,trigger_type)
@@ -2608,7 +2631,7 @@ EXECUTE FORMAT (
    'NOTIFY %s'
   ,in_notify_s);
 END $$;
-COMMENT ON FUNCTION exchange_do_insert_aml_decision(TEXT, BYTEA, BYTEA, INT8, INT8, TEXT, TEXT, BOOLEAN, TEXT, TEXT, TEXT, BYTEA, BYTEA, TEXT)
+COMMENT ON FUNCTION exchange_do_insert_aml_decision(TEXT, BYTEA, BYTEA, INT8, INT8, TEXT, TEXT, BOOLEAN, TEXT, TEXT, TEXT, BYTEA, BYTEA, TEXT, TEXT[])
   IS 'Checks whether the AML officer is eligible to make AML decisions and if so inserts the decision into the table';
 DROP FUNCTION IF EXISTS exchange_do_insert_successor_measure;
 CREATE FUNCTION exchange_do_insert_successor_measure(
@@ -2777,78 +2800,6 @@ UPDATE exchange.aml_staff
 END $$;
 COMMENT ON FUNCTION exchange_do_insert_aml_officer(BYTEA, BYTEA, TEXT, BOOL, BOOL, INT8)
   IS 'Inserts or updates AML staff record, making sure the update is more recent than the previous change';
-DROP FUNCTION IF EXISTS exchange_do_insert_kyc_measure_result;
-CREATE FUNCTION exchange_do_insert_kyc_measure_result(
-  IN in_process_row INT8,
-  IN in_h_payto BYTEA,
-  IN in_decision_time INT8,
-  IN in_expiration_time_ts INT8,
-  IN in_account_properties TEXT,
-  IN in_new_rules TEXT,
-  IN ina_events TEXT[],
-  IN in_to_investigate BOOLEAN,
-  IN in_kyc_completed_notify_s TEXT,
-  OUT out_ok BOOLEAN)
-LANGUAGE plpgsql
-AS $$
-DECLARE
-   my_trigger_outcome_serial INT8;
-   my_lmsi INT8;
-   my_i INT4;
-   ini_event TEXT;
-BEGIN
-UPDATE legitimization_outcomes
-   SET is_active=FALSE
- WHERE h_payto=in_h_payto
-   AND expiration_time >= in_decision_time;
-INSERT INTO legitimization_outcomes
-  (h_payto
-  ,decision_time
-  ,expiration_time
-  ,jproperties
-  ,to_investigate
-  ,jnew_rules)
-VALUES
-  (in_h_payto
-  ,in_decision_time
-  ,in_expiration_time_ts
-  ,in_account_properties
-  ,in_to_investigate
-  ,in_new_rules)
-RETURNING
-  outcome_serial_id
-INTO
-  my_trigger_outcome_serial;
-UPDATE legitimization_measures
-   SET is_finished=TRUE
- WHERE legitimization_measure_serial_id=
- (SELECT legitimization_measure_serial_id
-    FROM legitimization_processes
-   WHERE h_payto=in_h_payto
-     AND legitimization_process_serial_id=in_process_row);
-out_ok = FOUND;
-FOR i IN 1..COALESCE(array_length(ina_events,1),0)
-LOOP
-  ini_event = ina_events[i];
-  INSERT INTO kyc_events
-    (event_timestamp
-    ,event_type)
-    VALUES
-    (in_decision_time
-    ,ini_event);
-END LOOP;
-EXECUTE FORMAT (
- 'NOTIFY %s'
- ,in_kyc_completed_notify_s);
-INSERT INTO kyc_alerts
- (h_payto
- ,trigger_type)
- VALUES
- (in_h_payto,1)
- ON CONFLICT DO NOTHING;
-END $$;
-COMMENT ON FUNCTION exchange_do_insert_kyc_measure_result(INT8, BYTEA, INT8, INT8, TEXT, TEXT, TEXT[], BOOL, TEXT)
-  IS 'Inserts AML program outcome and updates the status of the legitimization process and the AML status for the account';
 DROP FUNCTION IF EXISTS exchange_do_array_reserves_insert;
 CREATE FUNCTION exchange_do_array_reserves_insert(
   IN in_gc_date INT8,
@@ -3835,4 +3786,57 @@ END IF;
 END $$;
 COMMENT ON FUNCTION exchange_do_set_aml_lock(BYTEA, INT8, INT8)
   IS 'Tries to lock an account for running an AML program. Returns the timeout of the existing lock, 0 if there is no existing lock, and NULL if we do not know the account.';
+DROP FUNCTION IF EXISTS exchange_do_insert_sanction_list_hit;
+CREATE FUNCTION exchange_do_insert_sanction_list_hit(
+  IN in_h_normalized_payto BYTEA,
+  IN in_decision_time INT8,
+  IN in_expiration_time INT8,
+  IN in_properties TEXT, 
+  IN in_new_rules TEXT, 
+  IN in_to_investigate BOOLEAN,
+  IN in_notify_s TEXT,
+  IN ina_events TEXT[],
+  OUT out_outcome_serial_id INT8)
+LANGUAGE plpgsql
+AS $$
+DECLARE
+  my_i INT4;
+  ini_event TEXT;
+BEGIN
+INSERT INTO legitimization_outcomes
+  (h_payto
+  ,decision_time
+  ,expiration_time
+  ,jproperties
+  ,to_investigate
+  ,jnew_rules
+  )
+  VALUES
+  (in_h_normalized_payto
+  ,in_decision_time
+  ,in_expiration_time
+  ,in_properties
+  ,in_to_investigate
+  ,in_new_rules
+  )
+  RETURNING
+    outcome_serial_id
+  INTO
+    out_outcome_serial_id;
+FOR i IN 1..COALESCE(array_length(ina_events,1),0)
+LOOP
+  ini_event = ina_events[i];
+  INSERT INTO kyc_events
+    (event_timestamp
+    ,event_type)
+    VALUES
+    (in_decision_time
+    ,ini_event);
+END LOOP;
+EXECUTE FORMAT (
+   'NOTIFY %s'
+  ,in_notify_s);
+END $$;
+COMMENT ON FUNCTION exchange_do_insert_sanction_list_hit(BYTEA, INT8, INT8, TEXT, TEXT, BOOLEAN, TEXT, TEXT[])
+  IS 'Insert result from sanction list check into the table';
 COMMIT;
