@@ -810,6 +810,7 @@ test_wire_fees (void)
   struct GNUNET_TIME_Timestamp ed;
   struct TALER_WireFeeSet fees2;
   struct TALER_MasterSignatureP ms;
+  uint64_t rowid;
 
   start_date = GNUNET_TIME_timestamp_get ();
   end_date = GNUNET_TIME_relative_to_timestamp (GNUNET_TIME_UNIT_MINUTES);
@@ -850,6 +851,7 @@ test_wire_fees (void)
       plugin->get_wire_fee (plugin->cls,
                             "wire-method",
                             end_date,
+                            &rowid,
                             &sd,
                             &ed,
                             &fees2,
@@ -862,6 +864,7 @@ test_wire_fees (void)
       plugin->get_wire_fee (plugin->cls,
                             "wire-method",
                             start_date,
+                            &rowid,
                             &sd,
                             &ed,
                             &fees2,
@@ -2112,7 +2115,7 @@ run (void *cls)
           break;
         }
       case TALER_EXCHANGEDB_TT_OLD_COIN_RECOUP:
-        /* TODO: check fields better... */
+        /* FIXME: check fields better... */
         matched |= 16;
         break;
       default:
