@@ -27,6 +27,7 @@
 #include "taler_exchangedb_plugin.h"
 #include "taler_bank_service.h"
 #include "taler_kyclogic_lib.h"
+#include "taler_util.h"
 
 
 /**
@@ -74,6 +75,12 @@ struct TALER_EXCHANGEDB_AccountInfo
    */
   const char *method;
 
+  /**
+   * Full payto://-URI of the account. Do not free(), aliased
+   * with the underlying `struct WireAccount`.
+   */
+  struct TALER_FullPayto payto_uri;
+
   /**
    * true if this account is enabled to be debited
    * by the taler-exchange-aggregator.
