@@ -598,6 +598,7 @@ TALER_KYCLOGIC_select_measure (
  * @param jmeasures a LegitimizationMeasures object
  * @param measure_index an index into the measures
  * @param form_data form data submitted for the measure
+ * @param[out] form_name set to the form name (on success)
  * @param[out] error_message set to error details
  * @return #TALER_EC_NONE if the form data matches the measure
  */
@@ -606,6 +607,7 @@ TALER_KYCLOGIC_check_form (
   const json_t *jmeasures,
   size_t measure_index,
   const json_t *form_data,
+  char **form_name,
   const char **error_message);
 
 
@@ -917,6 +919,11 @@ struct TALER_KYCLOGIC_AmlProgramResult
        */
       const json_t *new_rules;
 
+      /**
+       * New measures to trigger immediately.
+       */
+      const char *new_measures;
+
       /**
        * When do the new rules expire.
        */
@@ -1129,4 +1136,74 @@ void
 TALER_KYCLOGIC_run_aml_program_cancel (
   struct TALER_KYCLOGIC_AmlProgramRunnerHandle *aprh);
 
+
+/**
+ * Handle to a sanction list evaluation helper process.
+ */
+struct TALER_KYCLOGIC_SanctionRater;
+
+/**
+ * Function called with the result of a sanction evaluation.
+ *
+ * @param cls closure
+ * @param ec error code, #TALER_EC_NONE on success
+ * @param best_match identifies the sanction list entry with the best match
+ * @param expiration_time when does the sanction list entry expire
+ * @param rating likelihood of the match, from 0 (none) to 1 (perfect)
+ * @param confidence confidence in the evaluation, from 0 (none) to 1 (perfect)
+ */
+typedef void
+(*TALER_KYCLOGIC_SanctionResultCallback)(
+  void *cls,
+  enum TALER_ErrorCode ec,
+  const char *best_match,
+  struct GNUNET_TIME_Timestamp expiration_time,
+  double rating,
+  double confidence);
+
+
+/**
+ * Launch sanction rating helper process
+ *
+ * @param binary program name
+ * @param argv argument to give to the process
+ * @return handle for sanction list rating
+ */
+struct TALER_KYCLOGIC_SanctionRater *
+TALER_KYCLOGIC_sanction_rater_start (
+  const char *binary,
+  char *const*argv);
+
+
+/**
+ * KYC evaluation.
+ */
+struct TALER_KYCLOGIC_EvaluationEntry;
+
+/**
+ * Evaluate KYC attributes against sacntions list using @a sr
+ *
+ * @param[in,out] sr santion list evaluator
+ * @param attributes KYC attributes to evaluate
+ * @param cb function to call with the results
+ * @param cb_cls closure
+ * @return NULL on error
+ */
+struct TALER_KYCLOGIC_EvaluationEntry *
+TALER_KYCLOGIC_sanction_rater_eval (
+  struct TALER_KYCLOGIC_SanctionRater *sr,
+  const json_t *attributes,
+  TALER_KYCLOGIC_SanctionResultCallback cb,
+  void *cb_cls);
+
+
+/**
+ * Stop sanction rating helper process.
+ *
+ * @param[in] sr process to stop
+ */
+void
+TALER_KYCLOGIC_sanction_rater_stop (
+  struct TALER_KYCLOGIC_SanctionRater *sr);
+
 #endif
