@@ -103,20 +103,6 @@ MHD_RESULT
 TALER_MHD_can_compress (struct MHD_Connection *connection);
 
 
-/**
- * Check if @a mime matches the @a accept_pattern.  For this function, the @a
- * accept_pattern may include multiple values separated by ";".
- *
- * @param accept_pattern a mime pattern like "text/plain"
- *        or "image/STAR" or "text/plain; text/xml"
- * @param mime the mime type to match
- * @return true if @a mime matches the @a accept_pattern
- */
-bool
-TALER_MHD_xmime_matches (const char *accept_pattern,
-                         const char *mime);
-
-
 /**
  * Send JSON object as response.
  *
@@ -651,9 +637,8 @@ TALER_MHD_parse_request_arg_amount (struct MHD_Connection *connection,
 
 
 /**
- * Extract optional amount argument from request.
- * Macro that *returns* #MHD_YES/#MHD_NO if the
- * requested argument existed but failed to parse.
+ * Extract optional amount argument from request.  Macro that *returns*
+ * #MHD_YES/#MHD_NO if the requested argument existed but failed to parse.
  *
  * @param connection the MHD connection
  * @param name name of the argument to parse
@@ -677,28 +662,6 @@ TALER_MHD_parse_request_arg_amount (struct MHD_Connection *connection,
         } while (0)
 
 
-/**
- * Determines which of the given choices is preferred
- * by the client. Parses an HTTP header such as
- * "Accept:" or "Language:" to find entries matching
- * the list of strings given in the variadic argument
- * list. Returns the index of the preferred choice.
- *
- * @param connection HTTP request handle
- * @param header type of HTTP header to evaluate
- * @param ... NULL-terminated list of choices to
- *        check for in the header
- * @return -1 if none of the given choices is in
- *         the header, -2 if the header is missing,
- *         otherwise index of preferred choice in
- *         the varargs list
- */
-int
-TALER_MHD_check_accept (struct MHD_Connection *connection,
-                        const char *header,
-                        ...);
-
-
 /**
  * Extract fixed-size base32crockford encoded data from request argument.
  *
