@@ -441,15 +441,15 @@ TALER_is_web_url (const char *url);
  * which preference.
  * See also: https://tools.ietf.org/html/rfc7231#section-5.3.1
  *
- * @param language_pattern a language preferences string
+ * @param pattern a preferences string
  *        like "fr-CH, fr;q=0.9, en;q=0.8, *;q=0.1"
- * @param lang the 2-digit language to match
- * @return q-weight given for @a lang in @a language_pattern, 1.0 if no weights are given;
- *         0 if @a lang is not in @a language_pattern
+ * @param value the value to match
+ * @return q-weight given for @a value in @a pattern, 1.0 if no weights are given;
+ *         0 if @a value is not in @a pattern
  */
 double
-TALER_language_matches (const char *language_pattern,
-                        const char *lang);
+TALER_pattern_matches (const char *pattern,
+                       const char *value);
 
 
 /**
@@ -625,6 +625,17 @@ char *
 TALER_payto_validate (const struct TALER_FullPayto fpayto_uri);
 
 
+/**
+ * Check that a normalized payto:// URI is well-formed.
+ *
+ * @param npayto_uri the normalized URL to check
+ * @return NULL on success, otherwise an error
+ *         message to be freed by the caller!
+ */
+char *
+TALER_normalized_payto_validate (const struct TALER_NormalizedPayto npayto_uri);
+
+
 /**
  * Create payto://-URI for a given exchange base URL
  * and a @a reserve_pub.
