@@ -908,10 +908,10 @@ parse_denom_pub_cipher (void *cls,
 
 
 struct GNUNET_JSON_Specification
-TALER_JSON_spec_denom_pub_cipher (const char *field,
-                                  enum GNUNET_CRYPTO_BlindSignatureAlgorithm
-                                  cipher,
-                                  struct TALER_DenominationPublicKey *pk)
+TALER_JSON_spec_denom_pub_cipher (
+  const char *field,
+  enum GNUNET_CRYPTO_BlindSignatureAlgorithm cipher,
+  struct TALER_DenominationPublicKey *pk)
 {
   struct GNUNET_JSON_Specification ret = {
     .parser = &parse_denom_pub_cipher,
@@ -1129,8 +1129,8 @@ parse_i18n_string (void *cls,
     {
       double score;
 
-      score = TALER_language_matches (ctx->lp,
-                                      lang);
+      score = TALER_pattern_matches (ctx->lp,
+                                     lang);
       if (score > best)
       {
         best = score;
@@ -1399,11 +1399,10 @@ parse_normalized_payto_uri (void *cls,
     return GNUNET_SYSERR;
   }
   payto_uri->normalized_payto = (char *) str;
-#if FIXME /* need reduced validation for normalized paytos! */
   {
     char *err;
 
-    err = TALER_payto_validate (*payto_uri);
+    err = TALER_normalized_payto_validate (*payto_uri);
     if (NULL != err)
     {
       GNUNET_break_op (0);
@@ -1412,7 +1411,6 @@ parse_normalized_payto_uri (void *cls,
       return GNUNET_SYSERR;
     }
   }
-#endif
   return GNUNET_OK;
 }
 
@@ -1698,6 +1696,7 @@ parse_kycte (void *cls,
       }
     }
     GNUNET_break_op (0);
+    return GNUNET_SYSERR;
   }
   if (json_is_integer (root))
   {
