@@ -96,6 +96,47 @@ TALER_JSON_pack_age_commitment (
 }
 
 
+struct GNUNET_JSON_PackSpec
+TALER_JSON_pack_kycte (const char *name,
+                       enum TALER_KYCLOGIC_KycTriggerEvent event)
+{
+  const char *str = "INVALID";
+
+  switch (event)
+  {
+  case TALER_KYCLOGIC_KYC_TRIGGER_NONE:
+    str = "NONE";
+    break;
+  case TALER_KYCLOGIC_KYC_TRIGGER_WITHDRAW:
+    str = "WITHDRAW";
+    break;
+  case TALER_KYCLOGIC_KYC_TRIGGER_DEPOSIT:
+    str = "DEPOSIT";
+    break;
+  case TALER_KYCLOGIC_KYC_TRIGGER_P2P_RECEIVE:
+    str = "MERGE";
+    break;
+  case TALER_KYCLOGIC_KYC_TRIGGER_WALLET_BALANCE:
+    str = "BALANCE";
+    break;
+  case TALER_KYCLOGIC_KYC_TRIGGER_RESERVE_CLOSE:
+    str = "CLOSE";
+    break;
+  case TALER_KYCLOGIC_KYC_TRIGGER_AGGREGATE:
+    str = "AGGREGATE";
+    break;
+  case TALER_KYCLOGIC_KYC_TRIGGER_TRANSACTION:
+    str = "TRANSACTION";
+    break;
+  case TALER_KYCLOGIC_KYC_TRIGGER_REFUND:
+    str = "REFUND";
+    break;
+  }
+  return GNUNET_JSON_pack_string (name,
+                                  str);
+}
+
+
 struct GNUNET_JSON_PackSpec
 TALER_JSON_pack_denom_pub (
   const char *name,
@@ -120,7 +161,7 @@ TALER_JSON_pack_denom_pub (
                                    "RSA"),
           GNUNET_JSON_pack_uint64 ("age_mask",
                                    pk->age_mask.bits),
-          GNUNET_JSON_pack_rsa_public_key ("rsa_public_key",
+          GNUNET_JSON_pack_rsa_public_key ("rsa_pub",
                                            bsp->details.rsa_public_key));
     return ps;
   case GNUNET_CRYPTO_BSA_CS:
@@ -130,7 +171,47 @@ TALER_JSON_pack_denom_pub (
                                    "CS"),
           GNUNET_JSON_pack_uint64 ("age_mask",
                                    pk->age_mask.bits),
-          GNUNET_JSON_pack_data_varsize ("cs_public_key",
+          GNUNET_JSON_pack_data_varsize ("cs_pub",
+                                         &bsp->details.cs_public_key,
+                                         sizeof (bsp->details.cs_public_key)));
+    return ps;
+  }
+  GNUNET_assert (0);
+  return ps;
+}
+
+
+struct GNUNET_JSON_PackSpec
+TALER_JSON_pack_token_pub (
+  const char *name,
+  const struct TALER_TokenIssuePublicKey *pk)
+{
+  const struct GNUNET_CRYPTO_BlindSignPublicKey *bsp;
+  struct GNUNET_JSON_PackSpec ps = {
+    .field_name = name,
+  };
+
+  if (NULL == pk)
+    return ps;
+  bsp = pk->public_key;
+  switch (bsp->cipher)
+  {
+  case GNUNET_CRYPTO_BSA_INVALID:
+    break;
+  case GNUNET_CRYPTO_BSA_RSA:
+    ps.object
+      = GNUNET_JSON_PACK (
+          GNUNET_JSON_pack_string ("cipher",
+                                   "RSA"),
+          GNUNET_JSON_pack_rsa_public_key ("rsa_pub",
+                                           bsp->details.rsa_public_key));
+    return ps;
+  case GNUNET_CRYPTO_BSA_CS:
+    ps.object
+      = GNUNET_JSON_PACK (
+          GNUNET_JSON_pack_string ("cipher",
+                                   "CS"),
+          GNUNET_JSON_pack_data_varsize ("cs_pub",
                                          &bsp->details.cs_public_key,
                                          sizeof (bsp->details.cs_public_key)));
     return ps;
@@ -158,7 +239,7 @@ TALER_JSON_pack_denom_sig (
 struct GNUNET_JSON_PackSpec
 TALER_JSON_pack_token_issue_sig (
   const char *name,
-  const struct TALER_TokenIssueSignatureP *sig)
+  const struct TALER_TokenIssueSignature *sig)
 {
   struct GNUNET_JSON_PackSpec ps = {
     .field_name = name,
@@ -298,4 +379,24 @@ TALER_JSON_pack_amount (const char *name,
 }
 
 
+struct GNUNET_JSON_PackSpec
+TALER_JSON_pack_full_payto (
+  const char *name,
+  const struct TALER_FullPayto payto)
+{
+  return GNUNET_JSON_pack_string (name,
+                                  payto.full_payto);
+}
+
+
+struct GNUNET_JSON_PackSpec
+TALER_JSON_pack_normalized_payto (
+  const char *name,
+  const struct TALER_NormalizedPayto payto)
+{
+  return GNUNET_JSON_pack_string (name,
+                                  payto.normalized_payto);
+}
+
+
 /* End of json/json_pack.c */
