@@ -141,6 +141,8 @@ TALER_EXCHANGE_post_aml_decision (
   bool keep_investigating,
   const char *justification,
   const struct TALER_AmlOfficerPrivateKeyP *officer_priv,
+  unsigned int num_events,
+  const char **events,
   TALER_EXCHANGE_AddAmlDecisionCallback cb,
   void *cb_cls)
 {
@@ -152,7 +154,17 @@ TALER_EXCHANGE_post_aml_decision (
   json_t *new_rules;
   json_t *jrules;
   json_t *jmeasures;
+  json_t *jevents = NULL;
 
+  if (0 != num_events)
+  {
+    jevents = json_array ();
+    GNUNET_assert (NULL != jevents);
+    for (unsigned int i = 0; i<num_events; i++)
+      GNUNET_assert (0 ==
+                     json_array_append_new (jevents,
+                                            json_string (events[i])));
+  }
   jrules = json_array ();
   GNUNET_assert (NULL != jrules);
   for (unsigned int i = 0; i<num_rules; i++)
@@ -176,6 +188,9 @@ TALER_EXCHANGE_post_aml_decision (
                                  al->timeframe),
       GNUNET_JSON_pack_array_steal ("measures",
                                     ameasures),
+      GNUNET_JSON_pack_allow_null (
+        GNUNET_JSON_pack_array_steal ("events",
+                                      jevents)),
       GNUNET_JSON_pack_bool ("exposed",
                              al->exposed),
       GNUNET_JSON_pack_bool ("is_and_combinator",
