@@ -567,9 +567,7 @@ perform_protocol (
       /* The mask must be the same for all coins */
       FAIL_IF (awbh->age_mask.bits != denom_pub->key.age_mask.bits);
 
-      jdenom = GNUNET_JSON_PACK (
-        GNUNET_JSON_pack_data_auto (NULL,
-                                    denom_h));
+      jdenom = GNUNET_JSON_from_data_auto (denom_h);
       FAIL_IF (NULL == jdenom);
       FAIL_IF (0 > json_array_append_new (j_denoms,
                                           jdenom));
