@@ -54,9 +54,14 @@ struct CoinData
   const struct TALER_AgeCommitmentHash *ach;
 
   /**
-   *  blinding secret
+   * blinding secret
    */
-  union TALER_DenominationBlindingKeyP bks;
+  union GNUNET_CRYPTO_BlindingSecretP bks;
+
+  /**
+   * Session nonce.
+   */
+  union GNUNET_CRYPTO_BlindSessionNonce nonce;
 
   /**
    * Private key of the coin we are withdrawing.
@@ -69,7 +74,7 @@ struct CoinData
   struct TALER_PlanchetDetail pd;
 
   /**
-   * Values of the @cipher selected
+   * Values of the cipher selected
    */
   struct TALER_ExchangeWithdrawValues alg_values;
 
@@ -79,7 +84,7 @@ struct CoinData
   struct TALER_CoinPubHashP c_hash;
 
   /**
-   * Handler for the CS R request (only used for TALER_DENOMINATION_CS denominations)
+   * Handler for the CS R request (only used for GNUNET_CRYPTO_BSA_CS denominations)
    */
   struct TALER_EXCHANGE_CsRWithdrawHandle *csrh;
 
@@ -111,7 +116,6 @@ struct TALER_EXCHANGE_BatchWithdrawHandle
    */
   const struct TALER_EXCHANGE_Keys *keys;
 
-
   /**
    * Handle for the actual (internal) batch withdraw operation.
    */
@@ -295,30 +299,38 @@ withdraw_cs_stage_two_callback (
   };
 
   cd->csrh = NULL;
-  GNUNET_assert (TALER_DENOMINATION_CS == cd->pk.key.cipher);
+  GNUNET_assert (GNUNET_CRYPTO_BSA_CS ==
+                 cd->pk.key.bsign_pub_key->cipher);
   switch (csrr->hr.http_status)
   {
   case MHD_HTTP_OK:
-    cd->alg_values = csrr->details.ok.alg_values;
+    GNUNET_assert (NULL ==
+                   cd->alg_values.blinding_inputs);
+    TALER_denom_ewv_copy (&cd->alg_values,
+                          &csrr->details.ok.alg_values);
     TALER_planchet_setup_coin_priv (&cd->ps,
                                     &cd->alg_values,
                                     &cd->priv);
     TALER_planchet_blinding_secret_create (&cd->ps,
                                            &cd->alg_values,
                                            &cd->bks);
-    /* This initializes the 2nd half of the
-       wh->pd.blinded_planchet! */
     if (GNUNET_OK !=
         TALER_planchet_prepare (&cd->pk.key,
                                 &cd->alg_values,
                                 &cd->bks,
+                                &cd->nonce,
                                 &cd->priv,
                                 cd->ach,
                                 &cd->c_hash,
                                 &cd->pd))
     {
       GNUNET_break (0);
+      wr.hr.http_status = 0;
+      wr.hr.ec = TALER_EC_GENERIC_CLIENT_INTERNAL_ERROR;
+      wh->cb (wh->cb_cls,
+              &wr);
       TALER_EXCHANGE_batch_withdraw_cancel (wh);
+      return;
     }
     wh->cs_pending--;
     if (0 == wh->cs_pending)
@@ -365,59 +377,53 @@ TALER_EXCHANGE_batch_withdraw (
     cd->ps = *wci->ps;
     cd->ach = wci->ach;
     cd->pk = *wci->pk;
-    TALER_denom_pub_deep_copy (&cd->pk.key,
-                               &wci->pk->key);
-    switch (wci->pk->key.cipher)
+    TALER_denom_pub_copy (&cd->pk.key,
+                          &wci->pk->key);
+    switch (wci->pk->key.bsign_pub_key->cipher)
     {
-    case TALER_DENOMINATION_RSA:
+    case GNUNET_CRYPTO_BSA_RSA:
+      TALER_denom_ewv_copy (&cd->alg_values,
+                            TALER_denom_ewv_rsa_singleton ());
+      TALER_planchet_setup_coin_priv (&cd->ps,
+                                      &cd->alg_values,
+                                      &cd->priv);
+      TALER_planchet_blinding_secret_create (&cd->ps,
+                                             &cd->alg_values,
+                                             &cd->bks);
+      if (GNUNET_OK !=
+          TALER_planchet_prepare (&cd->pk.key,
+                                  &cd->alg_values,
+                                  &cd->bks,
+                                  NULL,
+                                  &cd->priv,
+                                  cd->ach,
+                                  &cd->c_hash,
+                                  &cd->pd))
       {
-        cd->alg_values.cipher = TALER_DENOMINATION_RSA;
-        TALER_planchet_setup_coin_priv (&cd->ps,
-                                        &cd->alg_values,
-                                        &cd->priv);
-        TALER_planchet_blinding_secret_create (&cd->ps,
-                                               &cd->alg_values,
-                                               &cd->bks);
-        if (GNUNET_OK !=
-            TALER_planchet_prepare (&cd->pk.key,
-                                    &cd->alg_values,
-                                    &cd->bks,
-                                    &cd->priv,
-                                    cd->ach,
-                                    &cd->c_hash,
-                                    &cd->pd))
-        {
-          GNUNET_break (0);
-          TALER_EXCHANGE_batch_withdraw_cancel (wh);
-          return NULL;
-        }
-        break;
+        GNUNET_break (0);
+        TALER_EXCHANGE_batch_withdraw_cancel (wh);
+        return NULL;
       }
-    case TALER_DENOMINATION_CS:
+      break;
+    case GNUNET_CRYPTO_BSA_CS:
+      TALER_cs_withdraw_nonce_derive (
+        &cd->ps,
+        &cd->nonce.cs_nonce);
+      cd->csrh = TALER_EXCHANGE_csr_withdraw (
+        curl_ctx,
+        exchange_url,
+        &cd->pk,
+        &cd->nonce.cs_nonce,
+        &withdraw_cs_stage_two_callback,
+        cd);
+      if (NULL == cd->csrh)
       {
-        TALER_cs_withdraw_nonce_derive (
-          &cd->ps,
-          &cd->pd.blinded_planchet.details.cs_blinded_planchet.nonce);
-        /* Note that we only initialize the first half
-           of the blinded_planchet here; the other part
-           will be done after the /csr-withdraw request! */
-        cd->pd.blinded_planchet.cipher = TALER_DENOMINATION_CS;
-        cd->csrh = TALER_EXCHANGE_csr_withdraw (
-          curl_ctx,
-          exchange_url,
-          &cd->pk,
-          &cd->pd.blinded_planchet.details.cs_blinded_planchet.nonce,
-          &withdraw_cs_stage_two_callback,
-          cd);
-        if (NULL == cd->csrh)
-        {
-          GNUNET_break (0);
-          TALER_EXCHANGE_batch_withdraw_cancel (wh);
-          return NULL;
-        }
-        wh->cs_pending++;
-        break;
+        GNUNET_break (0);
+        TALER_EXCHANGE_batch_withdraw_cancel (wh);
+        return NULL;
       }
+      wh->cs_pending++;
+      break;
     default:
       GNUNET_break (0);
       TALER_EXCHANGE_batch_withdraw_cancel (wh);
@@ -443,6 +449,7 @@ TALER_EXCHANGE_batch_withdraw_cancel (
       TALER_EXCHANGE_csr_withdraw_cancel (cd->csrh);
       cd->csrh = NULL;
     }
+    TALER_denom_ewv_free (&cd->alg_values);
     TALER_blinded_planchet_free (&cd->pd.blinded_planchet);
     TALER_denom_pub_free (&cd->pk.key);
   }
