@@ -275,7 +275,7 @@ TALER_EXCHANGE_check_purse_econtract_conflict_ (
 }
 
 
-// FIXME: should be used...
+// FIXME: should be used... - #9422
 enum GNUNET_GenericReturnValue
 TALER_EXCHANGE_check_coin_denomination_conflict_ (
   const json_t *proof,
@@ -651,4 +651,32 @@ TALER_EXCHANGE_free_accounts (
 }
 
 
+enum GNUNET_GenericReturnValue
+TALER_EXCHANGE_keys_test_account_allowed (
+  const struct TALER_EXCHANGE_Keys *keys,
+  bool check_credit,
+  const struct TALER_NormalizedPayto payto_uri)
+{
+  /* For all accounts of the exchange */
+  for (unsigned int i = 0; i<keys->accounts_len; i++)
+  {
+    const struct TALER_EXCHANGE_WireAccount *account
+      = &keys->accounts[i];
+
+    /* KYC auth transfers are never supported with conversion */
+    if (NULL != account->conversion_url)
+      continue;
+    /* filter by source account by credit_restrictions */
+    if (GNUNET_YES !=
+        TALER_EXCHANGE_test_account_allowed (account,
+                                             check_credit,
+                                             payto_uri))
+      continue;
+    /* exchange account is allowed, add it */
+    return true;
+  }
+  return false;
+}
+
+
 /* end of exchange_api_common.c */
