@@ -82,10 +82,11 @@ handle_auditor_enable_finished (void *cls,
 {
   struct TALER_EXCHANGE_ManagementAuditorEnableHandle *ah = cls;
   const json_t *json = response;
-  struct TALER_EXCHANGE_ManagementAuditorEnableResponse aer = {
+  struct TALER_EXCHANGE_ManagementAuditorEnableResponse auditor_enable_response
+    = {
     .hr.http_status = (unsigned int) response_code,
     .hr.reply = json
-  };
+    };
 
   ah->job = NULL;
   switch (response_code)
@@ -93,8 +94,8 @@ handle_auditor_enable_finished (void *cls,
   case MHD_HTTP_NO_CONTENT:
     break;
   case MHD_HTTP_FORBIDDEN:
-    aer.hr.ec = TALER_JSON_get_error_code (json);
-    aer.hr.hint = TALER_JSON_get_error_hint (json);
+    auditor_enable_response.hr.ec = TALER_JSON_get_error_code (json);
+    auditor_enable_response.hr.hint = TALER_JSON_get_error_hint (json);
     break;
   case MHD_HTTP_NOT_FOUND:
     GNUNET_log (GNUNET_ERROR_TYPE_ERROR,
@@ -102,34 +103,35 @@ handle_auditor_enable_finished (void *cls,
                 ah->url);
     if (NULL != json)
     {
-      aer.hr.ec = TALER_JSON_get_error_code (json);
-      aer.hr.hint = TALER_JSON_get_error_hint (json);
+      auditor_enable_response.hr.ec = TALER_JSON_get_error_code (json);
+      auditor_enable_response.hr.hint = TALER_JSON_get_error_hint (json);
     }
     else
     {
-      aer.hr.ec = TALER_EC_GENERIC_INVALID_RESPONSE;
-      aer.hr.hint = TALER_ErrorCode_get_hint (aer.hr.ec);
+      auditor_enable_response.hr.ec = TALER_EC_GENERIC_INVALID_RESPONSE;
+      auditor_enable_response.hr.hint = TALER_ErrorCode_get_hint (
+        auditor_enable_response.hr.ec);
     }
     break;
   case MHD_HTTP_CONFLICT:
-    aer.hr.ec = TALER_JSON_get_error_code (json);
-    aer.hr.hint = TALER_JSON_get_error_hint (json);
+    auditor_enable_response.hr.ec = TALER_JSON_get_error_code (json);
+    auditor_enable_response.hr.hint = TALER_JSON_get_error_hint (json);
     break;
   default:
     /* unexpected response code */
     GNUNET_break_op (0);
-    aer.hr.ec = TALER_JSON_get_error_code (json);
-    aer.hr.hint = TALER_JSON_get_error_hint (json);
+    auditor_enable_response.hr.ec = TALER_JSON_get_error_code (json);
+    auditor_enable_response.hr.hint = TALER_JSON_get_error_hint (json);
     GNUNET_log (GNUNET_ERROR_TYPE_ERROR,
                 "Unexpected response code %u/%d for exchange management auditor enable\n",
                 (unsigned int) response_code,
-                (int) aer.hr.ec);
+                (int) auditor_enable_response.hr.ec);
     break;
   }
   if (NULL != ah->cb)
   {
     ah->cb (ah->cb_cls,
-            &aer);
+            &auditor_enable_response);
     ah->cb = NULL;
   }
   TALER_EXCHANGE_management_enable_auditor_cancel (ah);
