@@ -121,69 +121,6 @@ struct TALER_MHD_Legal
 };
 
 
-/**
- * Check if @a mime matches the @a accept_pattern.
- *
- * @param accept_pattern a mime pattern like "text/plain"
- *        or "image/STAR"
- * @param mime the mime type to match
- * @return true if @a mime matches the @a accept_pattern
- */
-static bool
-mime_matches (const char *accept_pattern,
-              const char *mime)
-{
-  const char *da = strchr (accept_pattern, '/');
-  const char *dm = strchr (mime, '/');
-  const char *end;
-
-  if ( (NULL == da) ||
-       (NULL == dm) )
-    return (0 == strcmp ("*", accept_pattern));
-  // FIXME: use TALER_MHD_check_accept() here!
-  /* FIXME: eventually, we might want to parse the "q=$FLOAT"
-     part after the ';' and figure out which one is the
-     best/preferred match instead of returning a boolean... */
-  end = strchr (da, ';');
-  if (NULL == end)
-    end = &da[strlen (da)];
-  return
-    ( ( (1 == da - accept_pattern) &&
-        ('*' == *accept_pattern) ) ||
-      ( (da - accept_pattern == dm - mime) &&
-        (0 == strncasecmp (accept_pattern,
-                           mime,
-                           da - accept_pattern)) ) ) &&
-    ( (0 == strcmp (da, "/*")) ||
-      (0 == strncasecmp (da,
-                         dm,
-                         end - da)) );
-}
-
-
-bool
-TALER_MHD_xmime_matches (const char *accept_pattern,
-                         const char *mime)
-{
-  char *ap = GNUNET_strdup (accept_pattern);
-  char *sptr;
-
-  for (const char *tok = strtok_r (ap, ",", &sptr);
-       NULL != tok;
-       tok = strtok_r (NULL, ",", &sptr))
-  {
-    if (mime_matches (tok,
-                      mime))
-    {
-      GNUNET_free (ap);
-      return true;
-    }
-  }
-  GNUNET_free (ap);
-  return false;
-}
-
-
 MHD_RESULT
 TALER_MHD_reply_legal (struct MHD_Connection *conn,
                        struct TALER_MHD_Legal *legal)
@@ -229,6 +166,8 @@ TALER_MHD_reply_legal (struct MHD_Connection *conn,
   {
     const char *mime;
     const char *lang;
+    double best_mime_q = 0.0;
+    double best_lang_q = 0.0;
 
     mime = MHD_lookup_connection_value (conn,
                                         MHD_HEADER_KIND,
@@ -246,34 +185,44 @@ TALER_MHD_reply_legal (struct MHD_Connection *conn,
          NULL != p;
          p = p->next)
     {
-      if ( (NULL == t) ||
-           (TALER_MHD_xmime_matches (mime,
-                                     p->mime_type)) )
-      {
-        if (NULL == langs)
-        {
-          langs = GNUNET_strdup (p->language);
-        }
-        else if (NULL == strstr (langs,
-                                 p->language))
-        {
-          char *tmp = langs;
+      double q;
 
-          GNUNET_asprintf (&langs,
-                           "%s,%s",
-                           tmp,
-                           p->language);
-          GNUNET_free (tmp);
-        }
-        if ( (NULL == t) ||
-             (! TALER_MHD_xmime_matches (mime,
-                                         t->mime_type)) ||
-             (TALER_language_matches (lang,
-                                      p->language) >
-              TALER_language_matches (lang,
-                                      t->language) ) )
-          t = p;
+      q = TALER_pattern_matches (mime,
+                                 p->mime_type);
+      if (q > best_mime_q)
+        best_mime_q = q;
+    }
+    for (struct Terms *p = legal->terms_head;
+         NULL != p;
+         p = p->next)
+    {
+      double q;
+
+      q = TALER_pattern_matches (mime,
+                                 p->mime_type);
+      if (q < best_mime_q)
+        continue;
+      if (NULL == langs)
+      {
+        langs = GNUNET_strdup (p->language);
       }
+      else if (NULL == strstr (langs,
+                               p->language))
+      {
+        char *tmp = langs;
+
+        GNUNET_asprintf (&langs,
+                         "%s,%s",
+                         tmp,
+                         p->language);
+        GNUNET_free (tmp);
+      }
+      q = TALER_pattern_matches (langs,
+                                 p->language);
+      if (q < best_lang_q)
+        continue;
+      best_lang_q = q;
+      t = p;
     }
     GNUNET_log (GNUNET_ERROR_TYPE_DEBUG,
                 "Best match for %s/%s: %s / %s\n",
