@@ -268,8 +268,8 @@ fi
 STAGE="config"
 
 
-EXCHANGE_URL=$(taler-config -c "$CONF" -s "EXCHANGE" -o "BASE_URL")
-CURRENCY=$(taler-config -c "$CONF" -s "TALER" -o "CURRENCY")
+EXCHANGE_URL=$(taler-exchange-config -c "$CONF" -s "EXCHANGE" -o "BASE_URL")
+CURRENCY=$(taler-exchange-config -c "$CONF" -s "EXCHANGE" -o "CURRENCY")
 
 echo "Setting up for $CURRENCY at $EXCHANGE_URL"
 
@@ -336,13 +336,13 @@ register_fakebank_account() {
 
 if [[ "1" = "$START_BANK" ]]
 then
-    BANK_PORT=$(taler-config -c "$CONF" -s "libeufin-bank" -o "PORT")
+    BANK_PORT=$(taler-exchange-config -c "$CONF" -s "libeufin-bank" -o "PORT")
     BANK_URL="http://localhost:${BANK_PORT}/"
 fi
 
 if [[ "1" = "$START_FAKEBANK" ]]
 then
-    BANK_PORT=$(taler-config -c "$CONF" -s "BANK" -o "HTTP_PORT")
+    BANK_PORT=$(taler-exchange-config -c "$CONF" -s "BANK" -o "HTTP_PORT")
     BANK_URL="http://localhost:${BANK_PORT}/"
 fi
 
@@ -354,11 +354,13 @@ then
     libeufin-bank dbinit \
         -r \
         -c "$CONF" \
+        -L "$LOGLEVEL" \
         &> libeufin-bank-reset.log
     echo "DONE"
     echo -n "Launching bank ... "
     libeufin-bank serve \
       -c "$CONF" \
+      -L "$LOGLEVEL" \
       > libeufin-bank-stdout.log \
       2> libeufin-bank-stderr.log &
     echo $! > libeufin-bank.pid
@@ -385,15 +387,17 @@ then
     echo "OK"
     echo -n "Set admin password..."
     AUSER="admin"
-    APASS="secret"
+    APASS="secret-password"
     libeufin-bank \
       passwd \
       -c "$CONF" \
+      -L "$LOGLEVEL" \
       "$AUSER" "$APASS" \
       &> libeufin-bank-passwd.log
     libeufin-bank \
       edit-account \
       -c "$CONF" \
+      -L "$LOGLEVEL" \
       --debit_threshold="$CURRENCY:1000000" \
       "$AUSER" \
       &> libeufin-bank-debit-threshold.log
@@ -450,13 +454,13 @@ STAGE="accounts"
 if [ "1" = "$START_FAKEBANK" ]
 then
     echo -n "Register Fakebank users ..."
-    register_fakebank_account fortytwo x
-    register_fakebank_account fortythree x
-    register_fakebank_account exchange x
-    register_fakebank_account tor x
-    register_fakebank_account gnunet x
-    register_fakebank_account tutorial x
-    register_fakebank_account survey x
+    register_fakebank_account fortytwo password
+    register_fakebank_account fortythree password
+    register_fakebank_account exchange password
+    register_fakebank_account tor password
+    register_fakebank_account gnunet password
+    register_fakebank_account tutorial password
+    register_fakebank_account survey password
     echo " DONE"
 fi
 
@@ -467,13 +471,13 @@ then
     # the C helper for the add-incoming call.  Without this value,
     # libeufin-bank  won't find the target account to debit along a /add-incoming
     # call.
-    register_bank_account fortytwo x "User42" FR7630006000011234567890189
-    register_bank_account fortythree x "Forty Three"
-    register_bank_account exchange x "Exchange Company" DE989651
-    register_bank_account tor x "Tor Project"
-    register_bank_account gnunet x "GNUnet"
-    register_bank_account tutorial x "Tutorial"
-    register_bank_account survey x "Survey"
+    register_bank_account fortytwo password "User42" FR7630006000011234567890189
+    register_bank_account fortythree password "Forty Three"
+    register_bank_account exchange password "Exchange Company" DE989651
+    register_bank_account tor password "Tor Project"
+    register_bank_account gnunet password "GNUnet"
+    register_bank_account tutorial password "Tutorial"
+    register_bank_account survey password "Survey"
     echo " DONE"
 fi
 
@@ -482,15 +486,15 @@ STAGE="exchange"
 if [ "1" = "$START_EXCHANGE" ]
 then
     echo -n "Starting exchange ..."
-    EXCHANGE_PORT=$(taler-config -c "$CONF" -s EXCHANGE -o PORT)
-    SERVE=$(taler-config -c "$CONF" -s EXCHANGE -o SERVE)
+    EXCHANGE_PORT=$(taler-exchange-config -c "$CONF" -s EXCHANGE -o PORT)
+    SERVE=$(taler-exchange-config -c "$CONF" -s EXCHANGE -o SERVE)
     if [ "${SERVE}" = "unix" ]
     then
-        EXCHANGE_URL=$(taler-config -c "$CONF" -s EXCHANGE -o BASE_URL)
+        EXCHANGE_URL=$(taler-exchange-config -c "$CONF" -s EXCHANGE -o BASE_URL)
     else
         EXCHANGE_URL="http://localhost:${EXCHANGE_PORT}/"
     fi
-    MASTER_PRIV_FILE=$(taler-config -f -c "${CONF}" -s "EXCHANGE-OFFLINE" -o "MASTER_PRIV_FILE")
+    MASTER_PRIV_FILE=$(taler-exchange-config -f -c "${CONF}" -s "EXCHANGE-OFFLINE" -o "MASTER_PRIV_FILE")
     MASTER_PRIV_DIR=$(dirname "$MASTER_PRIV_FILE")
     mkdir -p "${MASTER_PRIV_DIR}"
     if [ ! -e "$MASTER_PRIV_FILE" ]
@@ -499,11 +503,11 @@ then
         echo -n "."
     fi
     MASTER_PUB=$(gnunet-ecc -p "${MASTER_PRIV_FILE}")
-    MPUB=$(taler-config -c "$CONF" -s exchange -o MASTER_PUBLIC_KEY)
+    MPUB=$(taler-exchange-config -c "$CONF" -s exchange -o MASTER_PUBLIC_KEY)
     if [ "$MPUB" != "$MASTER_PUB" ]
     then
         echo -n " patching master_pub ($MASTER_PUB)..."
-        taler-config -c "$CONF" -s exchange -o MASTER_PUBLIC_KEY -V "$MASTER_PUB"
+        taler-exchange-config -c "$CONF" -s exchange -o MASTER_PUBLIC_KEY -V "$MASTER_PUB"
     fi
     taler-exchange-dbinit -c "$CONF" --reset
     $USE_VALGRIND taler-exchange-secmod-eddsa \
@@ -538,9 +542,9 @@ then
         DONAU_URL="http://localhost:${DONAU_PORT}/"
     fi
     donau-dbinit -c "$CONF" --reset
-    $USE_VALGRIND taler-exchange-secmod-eddsa -c "$CONF" -L "$LOGLEVEL" -s donau 2> donau-secmod-eddsa.log &
-    $USE_VALGRIND taler-exchange-secmod-rsa -c "$CONF" -L "$LOGLEVEL" -s donau 2> donau-secmod-rsa.log &
-    $USE_VALGRIND taler-exchange-secmod-cs -c "$CONF" -L "$LOGLEVEL" -s donau 2> donau-secmod-cs.log &
+    $USE_VALGRIND donau-secmod-eddsa -c "$CONF" -L "$LOGLEVEL" 2> donau-secmod-eddsa.log &
+    $USE_VALGRIND donau-secmod-rsa -c "$CONF" -L "$LOGLEVEL" 2> donau-secmod-rsa.log &
+    $USE_VALGRIND donau-secmod-cs -c "$CONF" -L "$LOGLEVEL" 2> donau-secmod-cs.log &
     $USE_VALGRIND donau-httpd -c "$CONF" -L "$LOGLEVEL" 2> donau-httpd.log &
     echo " DONE"
 fi
@@ -585,30 +589,39 @@ fi
 
 STAGE="merchant"
 
+if [ -n "${USE_MERCHANT_EXCHANGE+x}" ]
+then
+    MEPUB=$(taler-merchant-config -c "$CONF" -s "${USE_MERCHANT_EXCHANGE}" -o MASTER_KEY)
+    MXPUB=${MASTER_PUB:-$(taler-exchange-config -c "$CONF" -s exchange -o MASTER_PUBLIC_KEY)}
+    if [ "$MEPUB" != "$MXPUB" ]
+    then
+        echo -n " patching master_pub ($MXPUB)..."
+        taler-merchant-config -c "$CONF" -s "${USE_MERCHANT_EXCHANGE}" -o MASTER_KEY -V "$MXPUB"
+    else
+        echo -n " with exchange $MXPUB ..."
+    fi
+fi
+
 if [ "1" = "$START_MERCHANT" ]
 then
     echo -n "Starting merchant ..."
-    if [ -n "${USE_MERCHANT_EXCHANGE+x}" ]
-    then
-        MEPUB=$(taler-config -c "$CONF" -s "${USE_MERCHANT_EXCHANGE}" -o MASTER_KEY)
-        MXPUB=${MASTER_PUB:-$(taler-config -c "$CONF" -s exchange -o MASTER_PUBLIC_KEY)}
-        if [ "$MEPUB" != "$MXPUB" ]
-        then
-            echo -n " patching master_pub ($MXPUB)..."
-            taler-config -c "$CONF" -s "${USE_MERCHANT_EXCHANGE}" -o MASTER_KEY -V "$MXPUB"
-        fi
-    fi
-    MERCHANT_TYPE=$(taler-config -c "$CONF" -s MERCHANT -o SERVE)
+    MERCHANT_TYPE=$(taler-merchant-config -c "$CONF" -s MERCHANT -o SERVE)
     if [ "unix" = "$MERCHANT_TYPE" ]
     then
-        MERCHANT_URL="$(taler-config -c "$CONF" -s MERCHANT -o BASE_URL)"
+        MERCHANT_URL="$(taler-merchant-config -c "$CONF" -s MERCHANT -o BASE_URL)"
     else
-        MERCHANT_PORT="$(taler-config -c "$CONF" -s MERCHANT -o PORT)"
+        MERCHANT_PORT="$(taler-merchant-config -c "$CONF" -s MERCHANT -o PORT)"
         MERCHANT_URL="http://localhost:${MERCHANT_PORT}/"
     fi
     taler-merchant-dbinit \
         -c "$CONF" \
         --reset &> taler-merchant-dbinit.log
+    $USE_VALGRIND taler-merchant-exchangekeyupdate \
+                  -c "$CONF" \
+                  -L "$LOGLEVEL" 2> taler-merchant-exchangekeyupdate.log &
+    $USE_VALGRIND taler-merchant-kyccheck \
+                  -c "$CONF" \
+                  -L "$LOGLEVEL" 2> taler-merchant-kyccheck.log &
     $USE_VALGRIND taler-merchant-httpd \
                   -c "$CONF" \
                   -L "$LOGLEVEL" 2> taler-merchant-httpd.log &
@@ -649,11 +662,11 @@ STAGE="sync"
 if [ "1" = "$START_BACKUP" ]
 then
     echo -n "Starting sync ..."
-    SYNC_PORT=$(taler-config -c "$CONF" -s SYNC -o PORT)
-    SERVE=$(taler-config -c "$CONF" -s SYNC -o SERVE)
+    SYNC_PORT=$(sync-config -c "$CONF" -s SYNC -o PORT)
+    SERVE=$(sync-config -c "$CONF" -s SYNC -o SERVE)
     if [ "${SERVE}" = "unix" ]
     then
-        SYNC_URL=$(taler-config -c "$CONF" -s SYNC -o BASE_URL)
+        SYNC_URL=$(sync-config -c "$CONF" -s SYNC -o BASE_URL)
     else
         SYNC_URL="http://localhost:${SYNC_PORT}/"
     fi
@@ -671,10 +684,10 @@ if [ "1" = "$START_CHALLENGER" ]
 then
     echo -n "Starting challenger ..."
     CHALLENGER_PORT=$(challenger-config -c "$CONF" -s CHALLENGER -o PORT)
-    SERVE=$(taler-config -c "$CONF" -s CHALLENGER -o SERVE)
+    SERVE=$(challenger-config -c "$CONF" -s CHALLENGER -o SERVE)
     if [ "${SERVE}" = "unix" ]
     then
-        CHALLENGER_URL=$(taler-config -c "$CONF" -s CHALLENGER -o BASE_URL)
+        CHALLENGER_URL=$(challenger-config -c "$CONF" -s CHALLENGER -o BASE_URL)
     else
         CHALLENGER_URL="http://localhost:${CHALLENGER_PORT}/"
     fi
@@ -686,16 +699,16 @@ then
                   -L "$LOGLEVEL" \
                   2> challenger-httpd.log &
     echo " DONE"
-    for SECTION in $(taler-config -c "$CONF" -S | grep kyc-provider)
+    for SECTION in $(taler-exchange-config -c "$CONF" -S | grep kyc-provider)
     do
-        LOGIC=$(taler-config -c "$CONF" -s "$SECTION" -o "LOGIC")
+        LOGIC=$(taler-exchange-config -c "$CONF" -s "$SECTION" -o "LOGIC")
         if [ "${LOGIC}" = "oauth2" ]
         then
-            INFO=$(taler-config -c "$CONF" -s "$SECTION" -o "KYC_OAUTH2_INFO_URL")
+            INFO=$(taler-exchange-config -c "$CONF" -s "$SECTION" -o "KYC_OAUTH2_INFO_URL")
             if [ "${CHALLENGER_URL}info" = "$INFO" ]
             then
                 echo -n "Enabling Challenger client for $SECTION"
-                CLIENT_SECRET=$(taler-config -c "$CONF" -s "$SECTION" -o "KYC_OAUTH2_CLIENT_SECRET")
+                CLIENT_SECRET=$(taler-exchange-config -c "$CONF" -s "$SECTION" -o "KYC_OAUTH2_CLIENT_SECRET")
                 RFC_8959_PREFIX="secret-token:"
                 if ! echo "${CLIENT_SECRET}" | grep ^${RFC_8959_PREFIX} > /dev/null
                 then
@@ -703,7 +716,7 @@ then
                 fi
                 REDIRECT_URI="${EXCHANGE_URL}kyc-proof/kyc-provider-example-challeger"
                 CLIENT_ID=$(challenger-admin --add="${CLIENT_SECRET}" --quiet "${REDIRECT_URI}")
-                taler-config -c "$CONF" -s "$SECTION" -o KYC_OAUTH2_CLIENT_ID -V "$CLIENT_ID"
+                taler-exchange-config -c "$CONF" -s "$SECTION" -o KYC_OAUTH2_CLIENT_ID -V "$CLIENT_ID"
                 echo " DONE"
             fi
         fi
@@ -716,10 +729,10 @@ if [ "1" = "$START_AUDITOR" ]
 then
     echo -n "Starting auditor ..."
 
-    export TALER_AUDITOR_SALT=$(taler-config -c "$CONF" -s AUDITOR -o TALER_AUDITOR_SALT)
+    export TALER_AUDITOR_SALT=$(taler-auditor-config -c "$CONF" -s AUDITOR -o TALER_AUDITOR_SALT)
 
-    AUDITOR_URL=$(taler-config -c "$CONF" -s AUDITOR -o BASE_URL)
-    AUDITOR_PRIV_FILE=$(taler-config -f -c "$CONF" -s AUDITOR -o AUDITOR_PRIV_FILE)
+    AUDITOR_URL=$(taler-auditor-config -c "$CONF" -s AUDITOR -o BASE_URL)
+    AUDITOR_PRIV_FILE=$(taler-auditor-config -f -c "$CONF" -s AUDITOR -o AUDITOR_PRIV_FILE)
     AUDITOR_PRIV_DIR=$(dirname "$AUDITOR_PRIV_FILE")
     mkdir -p "$AUDITOR_PRIV_DIR"
     if [ ! -e "$AUDITOR_PRIV_FILE" ]
@@ -728,19 +741,24 @@ then
         echo -n "."
     fi
     AUDITOR_PUB=$(gnunet-ecc -p "${AUDITOR_PRIV_FILE}")
-    MAPUB=${MASTER_PUB:-$(taler-config -c "$CONF" -s exchange -o MASTER_PUBLIC_KEY)}
+    APUB=$(taler-exchange-config -c "$CONF" -s auditor -o PUBLIC_KEY)
+    if [ "$APUB" != "$AUDITOR_PUB" ]
+    then
+        echo -n " patching auditor public key ..."
+        # Using taler-exchange-config is correct here, we don't want to
+        # suddenly use the auditor-defaults while editing...
+        taler-exchange-config -c "$CONF" -s auditor -o PUBLIC_KEY -V "$AUDITOR_PUB"
+    fi
+
     taler-auditor-dbinit \
         -c "$CONF" \
         --reset
+    echo "Launching auditor using $CONF" > taler-auditor-httpd.log
+    echo "Launching auditor using $AUDITOR_PUB from $AUDITOR_PRIV_FILE" \
+         >> taler-auditor-httpd.log
     $USE_VALGRIND taler-auditor-httpd \
                   -L "$LOGLEVEL" \
-                  -c "$CONF" 2> taler-auditor-httpd.log &
-#    $USE_VALGRIND taler-helper-auditor-deposits \
-#                  -L "$LOGLEVEL" \
-#                  -c "$CONF" 2> taler-helper-auditor.log &
-
-
-
+                  -c "$CONF" 2>> taler-auditor-httpd.log &
     echo " DONE"
 fi
 
@@ -749,6 +767,7 @@ STAGE="wait"
 echo -n "Waiting for Taler services ..."
 # Wait for all other taler services to be available
 E_DONE=0
+D_DONE=0
 M_DONE=0
 S_DONE=0
 K_DONE=0
@@ -768,6 +787,17 @@ do
             -O /dev/null >/dev/null || continue
         E_DONE=1
     fi
+   if [ "0" = "$D_DONE" ] && [ "1" = "$START_DONAU" ]
+    then
+        echo -n "D"
+        wget \
+            --tries=1 \
+            --timeout=1 \
+            "${DONAU_URL}config" \
+            -o /dev/null \
+            -O /dev/null >/dev/null || continue
+        D_DONE=1
+    fi
     if [ "0" = "$M_DONE" ] && [ "1" = "$START_MERCHANT" ]
     then
         echo -n "M"
@@ -817,7 +847,7 @@ do
 done
 if [ 1 != "$OK" ]
 then
-    exit_skip "Failed to launch (some) Taler services"
+    exit_skip "Failed to launch (some) Taler services (E: $E_DONE, M: $M_DONE, S: $S_DONE, K: $K_DONE, A: $A_DONE, D: $D_DONE)"
 fi
 echo " OK"
 
@@ -858,11 +888,11 @@ then
       global-fee now "$CURRENCY:0.01" "$CURRENCY:0.01" "$CURRENCY:0.0" 1h 1year 5 \
       upload &> taler-exchange-offline.log
     echo "OK"
-    ENABLED=$(taler-config -c "$CONF" -s "$USE_ACCOUNT" -o "ENABLE_CREDIT")
+    ENABLED=$(taler-exchange-config -c "$CONF" -s "$USE_ACCOUNT" -o "ENABLE_CREDIT")
     if [ "YES" = "$ENABLED" ]
     then
         echo -n "Configuring bank account $USE_ACCOUNT ..."
-        EXCHANGE_PAYTO_URI=$(taler-config -c "$CONF" -s "$USE_ACCOUNT" -o "PAYTO_URI")
+        EXCHANGE_PAYTO_URI=$(taler-exchange-config -c "$CONF" -s "$USE_ACCOUNT" -o "PAYTO_URI")
         taler-exchange-offline -c "$CONF" \
           enable-account "$EXCHANGE_PAYTO_URI" \
           upload &> "taler-exchange-offline-account.log"
