@@ -1,6 +1,6 @@
 /*
   This file is part of TALER
-  Copyright (C) 2016-2020 Taler Systems SA
+  Copyright (C) 2016-2023 Taler Systems SA
 
   TALER is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as
@@ -76,7 +76,7 @@ run (void *cls,
     ssoptions = "-f";
     break;
   case TALER_TESTING_BS_IBAN:
-    ssoptions = "-ns";
+    ssoptions = "-b";
     break;
   default:
     ssoptions = NULL;
@@ -98,7 +98,7 @@ run (void *cls,
                                       1),
       TALER_TESTING_cmd_admin_add_incoming ("credit-1",
                                             "EUR:5.01",
-                                            &cred.ba,
+                                            &cred.ba_admin,
                                             cred.user42_payto),
       /**
        * This CMD doesn't care about the HTTP response code; that's
@@ -108,12 +108,10 @@ run (void *cls,
        */
       TALER_TESTING_cmd_admin_add_incoming_with_ref ("credit-1-fail",
                                                      "EUR:2.01",
-                                                     &cred.ba,
+                                                     &cred.ba_admin,
                                                      cred.user42_payto,
                                                      "credit-1",
                                                      -1),
-      TALER_TESTING_cmd_sleep ("Waiting 4s for 'credit-1' to settle",
-                               4),
       /**
        * Check that the incoming payment with a duplicate
        * reserve public key didn't make it to the exchange.
@@ -128,7 +126,7 @@ run (void *cls,
                                      5),
       TALER_TESTING_cmd_admin_add_incoming ("credit-2",
                                             "EUR:3.21",
-                                            &cred.ba,
+                                            &cred.ba_admin,
                                             cred.user42_payto),
       TALER_TESTING_cmd_transfer ("debit-1",
                                   "EUR:3.22",
@@ -137,18 +135,6 @@ run (void *cls,
                                   cred.user42_payto,
                                   &wtid,
                                   "http://exchange.example.com/"),
-
-      TALER_TESTING_cmd_sleep ("Waiting 5s for 'debit-1' to settle",
-                               5),
-      (bs == TALER_TESTING_BS_IBAN)
-      ? TALER_TESTING_cmd_nexus_fetch_transactions (
-        "fetch-transactions-at-nexus",
-        "exchange", /* from taler-nexus-prepare */
-        "x", /* from taler-nexus-prepare */
-        "http://localhost:8082",
-        "exchange-nexus") /* from taler-nexus-prepare */
-      : TALER_TESTING_cmd_sleep ("nop",
-                                 0),
       TALER_TESTING_cmd_bank_debits ("history-2b",
                                      &cred.ba,
                                      NULL,
@@ -181,6 +167,15 @@ main (int argc,
   {
     bs = TALER_TESTING_BS_IBAN;
     cfgfile = CONFIG_FILE_NEXUS;
+    if (GNUNET_SYSERR ==
+        GNUNET_OS_check_helper_binary ("libeufin-bank",
+                                       false,
+                                       NULL))
+    {
+      fprintf (stderr,
+               "libeufin-bank not found. Skipping test.\n");
+      return 77;
+    }
   }
   else
   {
