@@ -325,14 +325,14 @@ run (void *cls,
         GNUNET_TIME_UNIT_SECONDS,
         1), /* expiration */
       "withdraw-coin-1",
-      "EUR:1.01",
+      "EUR:1.02",
       NULL),
     TALER_TESTING_cmd_purse_poll (
       "push-poll-purse-before-expire",
       MHD_HTTP_GONE,
       "purse-with-deposit-expire",
       "EUR:1",
-      true,
+      true, /* wait for merge */
       GNUNET_TIME_UNIT_MINUTES),
     /* This should fail, as too much of the coin
        is already spend / in a purse */
@@ -484,14 +484,14 @@ run (void *cls,
     TALER_TESTING_cmd_reserve_close (
       "reserve-101-close-kyc",
       "create-reserve-101",
-      /* 42b => not to origin */
-      "payto://x-taler-bank/localhost/42b?receiver-name=42b",
+      /* 44 => not to origin */
+      cred.user44_payto,
       MHD_HTTP_UNAVAILABLE_FOR_LEGAL_REASONS),
     TALER_TESTING_cmd_admin_add_kycauth (
       "setup-account-key",
       "EUR:0.01",
       &cred.ba,
-      "payto://x-taler-bank/localhost/42b?receiver-name=42b",
+      cred.user44_payto,
       NULL /* create new key */),
     CMD_EXEC_WIREWATCH (
       "import-kyc-account"),
@@ -499,6 +499,7 @@ run (void *cls,
       "check-kyc-close-pending",
       "reserve-101-close-kyc",
       "setup-account-key",
+      TALER_EXCHANGE_KLPT_KYC_AUTH_TRANSFER,
       MHD_HTTP_ACCEPTED),
     TALER_TESTING_cmd_get_kyc_info (
       "get-kyc-info",
@@ -519,13 +520,14 @@ run (void *cls,
       "check-kyc-close-ok",
       "reserve-101-close-kyc",
       "setup-account-key",
+      TALER_EXCHANGE_KLPT_KYC_OK,
       MHD_HTTP_OK),
     /* Now it should pass */
     TALER_TESTING_cmd_reserve_close (
       "reserve-101-close",
       "create-reserve-101",
-      /* 42b => not to origin */
-      "payto://x-taler-bank/localhost/42b?receiver-name=42b",
+      /* 44 => not to origin */
+      cred.user44_payto,
       MHD_HTTP_OK),
     TALER_TESTING_cmd_exec_closer (
       "close-reserves-101",
