@@ -1,6 +1,6 @@
 /*
   This file is part of TALER
-  Copyright (C) 2018, 2021 Taler Systems SA
+  Copyright (C) 2018-2023 Taler Systems SA
 
   TALER is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by
@@ -59,20 +59,15 @@ struct DepositConfirmationState
   const char *amount_without_fee;
 
   /**
-   * Which coin of the @e deposit_reference should we confirm.
+   * How many coins were there in the @e deposit_reference?
    */
-  unsigned int coin_index;
+  unsigned int num_coins;
 
   /**
    * DepositConfirmation handle while operation is running.
    */
   struct TALER_AUDITOR_DepositConfirmationHandle *dc;
 
-  /**
-   * Auditor connection.
-   */
-  struct TALER_AUDITOR_Handle *auditor;
-
   /**
    * Interpreter state.
    */
@@ -125,8 +120,7 @@ do_retry (void *cls)
   struct DepositConfirmationState *dcs = cls;
 
   dcs->retry_task = NULL;
-  dcs->is->commands[dcs->is->ip].last_req_time
-    = GNUNET_TIME_absolute_get ();
+  TALER_TESTING_touch_cmd (dcs->is);
   deposit_confirmation_run (dcs,
                             NULL,
                             dcs->is);
@@ -138,13 +132,15 @@ do_retry (void *cls)
  * to check if the response code is acceptable.
  *
  * @param cls closure.
- * @param hr HTTP response details
+ * @param dcr response details
  */
 static void
-deposit_confirmation_cb (void *cls,
-                         const struct TALER_AUDITOR_HttpResponse *hr)
+deposit_confirmation_cb (
+  void *cls,
+  const struct TALER_AUDITOR_DepositConfirmationResponse *dcr)
 {
   struct DepositConfirmationState *dcs = cls;
+  const struct TALER_AUDITOR_HttpResponse *hr = &dcr->hr;
 
   dcs->dc = NULL;
   if (dcs->expected_response_code != hr->http_status)
@@ -166,21 +162,16 @@ deposit_confirmation_cb (void *cls,
         else
           dcs->backoff = GNUNET_TIME_randomized_backoff (dcs->backoff,
                                                          MAX_BACKOFF);
-        dcs->is->commands[dcs->is->ip].num_tries++;
+        TALER_TESTING_inc_tries (dcs->is);
         dcs->retry_task = GNUNET_SCHEDULER_add_delayed (dcs->backoff,
                                                         &do_retry,
                                                         dcs);
         return;
       }
     }
-    GNUNET_log (GNUNET_ERROR_TYPE_ERROR,
-                "Unexpected response code %u to command %s in %s:%u\n",
-                hr->http_status,
-                dcs->is->commands[dcs->is->ip].label,
-                __FILE__,
-                __LINE__);
-    json_dumpf (hr->reply, stderr, 0);
-    TALER_TESTING_interpreter_fail (dcs->is);
+    TALER_TESTING_unexpected_status (dcs->is,
+                                     hr->http_status,
+                                     dcs->expected_response_code);
     return;
   }
   TALER_TESTING_interpreter_next (dcs->is);
@@ -210,20 +201,43 @@ deposit_confirmation_run (void *cls,
   struct GNUNET_TIME_Timestamp refund_deadline
     = GNUNET_TIME_UNIT_ZERO_TS;
   struct TALER_Amount amount_without_fee;
-  struct TALER_CoinSpendPublicKeyP coin_pub;
+  struct TALER_CoinSpendPublicKeyP coin_pubs[dcs->num_coins];
+  const struct TALER_CoinSpendPublicKeyP *coin_pubps[dcs->num_coins];
+  const struct TALER_CoinSpendSignatureP *coin_sigps[dcs->num_coins];
   const struct TALER_MerchantPrivateKeyP *merchant_priv;
   struct TALER_MerchantPublicKeyP merchant_pub;
   const struct TALER_ExchangePublicKeyP *exchange_pub;
   const struct TALER_ExchangeSignatureP *exchange_sig;
   const json_t *wire_details;
   const json_t *contract_terms;
-  const struct TALER_CoinSpendPrivateKeyP *coin_priv;
   const struct TALER_EXCHANGE_Keys *keys;
   const struct TALER_EXCHANGE_SigningPublicKey *spk;
+  const char *auditor_url;
 
   (void) cmd;
   dcs->is = is;
   GNUNET_assert (NULL != dcs->deposit_reference);
+  {
+    const struct TALER_TESTING_Command *auditor_cmd;
+
+    auditor_cmd
+      = TALER_TESTING_interpreter_get_command (is,
+                                               "auditor");
+    if (NULL == auditor_cmd)
+    {
+      GNUNET_break (0);
+      TALER_TESTING_interpreter_fail (is);
+      return;
+    }
+    if (GNUNET_OK !=
+        TALER_TESTING_get_trait_auditor_url (auditor_cmd,
+                                             &auditor_url))
+    {
+      GNUNET_break (0);
+      TALER_TESTING_interpreter_fail (is);
+      return;
+    }
+  }
   deposit_cmd
     = TALER_TESTING_interpreter_lookup_command (is,
                                                 dcs->deposit_reference);
@@ -236,22 +250,22 @@ deposit_confirmation_run (void *cls,
 
   GNUNET_assert (GNUNET_OK ==
                  TALER_TESTING_get_trait_exchange_pub (deposit_cmd,
-                                                       dcs->coin_index,
+                                                       0,
                                                        &exchange_pub));
   GNUNET_assert (GNUNET_OK ==
                  TALER_TESTING_get_trait_exchange_sig (deposit_cmd,
-                                                       dcs->coin_index,
+                                                       0,
                                                        &exchange_sig));
   GNUNET_assert (GNUNET_OK ==
                  TALER_TESTING_get_trait_timestamp (deposit_cmd,
-                                                    dcs->coin_index,
+                                                    0,
                                                     &exchange_timestamp));
   GNUNET_assert (GNUNET_OK ==
                  TALER_TESTING_get_trait_wire_deadline (deposit_cmd,
-                                                        dcs->coin_index,
+                                                        0,
                                                         &wire_deadline));
   GNUNET_assert (NULL != exchange_timestamp);
-  keys = TALER_EXCHANGE_get_keys (dcs->is->exchange);
+  keys = TALER_TESTING_get_keys (is);
   GNUNET_assert (NULL != keys);
   spk = TALER_EXCHANGE_get_signing_key_info (keys,
                                              exchange_pub);
@@ -270,12 +284,23 @@ deposit_confirmation_run (void *cls,
   GNUNET_assert (GNUNET_OK ==
                  TALER_JSON_merchant_wire_signature_hash (wire_details,
                                                           &h_wire));
-  GNUNET_assert (GNUNET_OK ==
-                 TALER_TESTING_get_trait_coin_priv (deposit_cmd,
-                                                    dcs->coin_index,
-                                                    &coin_priv));
-  GNUNET_CRYPTO_eddsa_key_get_public (&coin_priv->eddsa_priv,
-                                      &coin_pub.eddsa_pub);
+
+  for (unsigned int i = 0; i<dcs->num_coins; i++)
+  {
+    const struct TALER_CoinSpendPrivateKeyP *coin_priv;
+
+    GNUNET_assert (GNUNET_OK ==
+                   TALER_TESTING_get_trait_coin_priv (deposit_cmd,
+                                                      i,
+                                                      &coin_priv));
+    GNUNET_CRYPTO_eddsa_key_get_public (&coin_priv->eddsa_priv,
+                                        &coin_pubs[i].eddsa_pub);
+    coin_pubps[i] = &coin_pubs[i];
+    GNUNET_assert (GNUNET_OK ==
+                   TALER_TESTING_get_trait_coin_sig (deposit_cmd,
+                                                     i,
+                                                     &coin_sigps[i]));
+  }
   GNUNET_assert (GNUNET_OK ==
                  TALER_TESTING_get_trait_merchant_priv (deposit_cmd,
                                                         &merchant_priv));
@@ -308,25 +333,29 @@ deposit_confirmation_run (void *cls,
     if (GNUNET_TIME_absolute_is_zero (refund_deadline.abs_time))
       refund_deadline = timestamp;
   }
-  dcs->dc = TALER_AUDITOR_deposit_confirmation (dcs->auditor,
-                                                &h_wire,
-                                                &no_h_policy,
-                                                &h_contract_terms,
-                                                *exchange_timestamp,
-                                                *wire_deadline,
-                                                refund_deadline,
-                                                &amount_without_fee,
-                                                &coin_pub,
-                                                &merchant_pub,
-                                                exchange_pub,
-                                                exchange_sig,
-                                                &keys->master_pub,
-                                                spk->valid_from,
-                                                spk->valid_until,
-                                                spk->valid_legal,
-                                                &spk->master_sig,
-                                                &deposit_confirmation_cb,
-                                                dcs);
+  dcs->dc = TALER_AUDITOR_deposit_confirmation (
+    TALER_TESTING_interpreter_get_context (is),
+    auditor_url,
+    &h_wire,
+    &no_h_policy,
+    &h_contract_terms,
+    *exchange_timestamp,
+    *wire_deadline,
+    refund_deadline,
+    &amount_without_fee,
+    dcs->num_coins,
+    coin_pubps,
+    coin_sigps,
+    &merchant_pub,
+    exchange_pub,
+    exchange_sig,
+    &keys->master_pub,
+    spk->valid_from,
+    spk->valid_until,
+    spk->valid_legal,
+    &spk->master_sig,
+    &deposit_confirmation_cb,
+    dcs);
 
   if (NULL == dcs->dc)
   {
@@ -353,10 +382,8 @@ deposit_confirmation_cleanup (void *cls,
 
   if (NULL != dcs->dc)
   {
-    GNUNET_log (GNUNET_ERROR_TYPE_WARNING,
-                "Command %u (%s) did not complete\n",
-                dcs->is->ip,
-                cmd->label);
+    TALER_TESTING_command_incomplete (dcs->is,
+                                      cmd->label);
     TALER_AUDITOR_deposit_confirmation_cancel (dcs->dc);
     dcs->dc = NULL;
   }
@@ -371,18 +398,16 @@ deposit_confirmation_cleanup (void *cls,
 
 struct TALER_TESTING_Command
 TALER_TESTING_cmd_deposit_confirmation (const char *label,
-                                        struct TALER_AUDITOR_Handle *auditor,
                                         const char *deposit_reference,
-                                        unsigned int coin_index,
+                                        unsigned int num_coins,
                                         const char *amount_without_fee,
                                         unsigned int expected_response_code)
 {
   struct DepositConfirmationState *dcs;
 
   dcs = GNUNET_new (struct DepositConfirmationState);
-  dcs->auditor = auditor;
   dcs->deposit_reference = deposit_reference;
-  dcs->coin_index = coin_index;
+  dcs->num_coins = num_coins;
   dcs->amount_without_fee = amount_without_fee;
   dcs->expected_response_code = expected_response_code;
 
