@@ -33,6 +33,22 @@
 struct KycCheckGetState
 {
 
+  /**
+   * Set to the KYC URL *if* the exchange replied with
+   * a request for KYC (#MHD_HTTP_ACCEPTED or #MHD_HTTP_OK).
+   */
+  struct TALER_AccountAccessTokenP access_token;
+
+  /**
+   * Handle to the "track transaction" pending operation.
+   */
+  struct TALER_EXCHANGE_KycCheckHandle *kwh;
+
+  /**
+   * Interpreter state.
+   */
+  struct TALER_TESTING_Interpreter *is;
+
   /**
    * Command to get a reserve private key from.
    */
@@ -49,20 +65,10 @@ struct KycCheckGetState
   unsigned int expected_response_code;
 
   /**
-   * Set to the KYC URL *if* the exchange replied with
-   * a request for KYC (#MHD_HTTP_ACCEPTED or #MHD_HTTP_OK).
+   * What are we waiting for when long-polling?
    */
-  struct TALER_AccountAccessTokenP access_token;
+  enum TALER_EXCHANGE_KycLongPollTarget lpt;
 
-  /**
-   * Handle to the "track transaction" pending operation.
-   */
-  struct TALER_EXCHANGE_KycCheckHandle *kwh;
-
-  /**
-   * Interpreter state.
-   */
-  struct TALER_TESTING_Interpreter *is;
 };
 
 
@@ -120,7 +126,7 @@ check_kyc_run (void *cls,
   struct KycCheckGetState *kcg = cls;
   const struct TALER_TESTING_Command *res_cmd;
   const struct TALER_TESTING_Command *acc_cmd;
-  const uint64_t *requirement_row;
+  const struct TALER_NormalizedPaytoHashP *h_payto;
   const union TALER_AccountPrivateKeyP *account_priv;
 
   (void) cmd;
@@ -144,9 +150,9 @@ check_kyc_run (void *cls,
     return;
   }
   if (GNUNET_OK !=
-      TALER_TESTING_get_trait_legi_requirement_row (
+      TALER_TESTING_get_trait_h_normalized_payto (
         res_cmd,
-        &requirement_row))
+        &h_payto))
   {
     GNUNET_break (0);
     TALER_TESTING_interpreter_fail (kcg->is);
@@ -160,7 +166,7 @@ check_kyc_run (void *cls,
     TALER_TESTING_interpreter_fail (kcg->is);
     return;
   }
-  if (0 == *requirement_row)
+  if (0 == h_payto)
   {
     GNUNET_break (0);
     TALER_TESTING_interpreter_fail (kcg->is);
@@ -169,9 +175,12 @@ check_kyc_run (void *cls,
   kcg->kwh = TALER_EXCHANGE_kyc_check (
     TALER_TESTING_interpreter_get_context (is),
     TALER_TESTING_get_exchange_url (is),
-    *requirement_row,
+    h_payto,
     account_priv,
-    GNUNET_TIME_UNIT_ZERO,
+    kcg->lpt,
+    TALER_EXCHANGE_KLPT_NONE == kcg->lpt
+    ? GNUNET_TIME_UNIT_ZERO
+    : GNUNET_TIME_UNIT_MINUTES,
     &check_kyc_cb,
     kcg);
   GNUNET_assert (NULL != kcg->kwh);
@@ -235,6 +244,7 @@ TALER_TESTING_cmd_check_kyc_get (
   const char *label,
   const char *payment_target_reference,
   const char *account_reference,
+  enum TALER_EXCHANGE_KycLongPollTarget lpt,
   unsigned int expected_response_code)
 {
   struct KycCheckGetState *kcg;
@@ -243,6 +253,7 @@ TALER_TESTING_cmd_check_kyc_get (
   kcg->payment_target_reference = payment_target_reference;
   kcg->account_reference = account_reference;
   kcg->expected_response_code = expected_response_code;
+  kcg->lpt = lpt;
   {
     struct TALER_TESTING_Command cmd = {
       .cls = kcg,
