@@ -221,7 +221,7 @@ handle_mt_avail (struct TALER_CRYPTO_CsDenominationHelper *dh,
                         sizeof (bsign_pub->details.cs_public_key),
                         &bsign_pub->pub_key_hash);
     h_cs.hash = bsign_pub->pub_key_hash;
-    GNUNET_log (GNUNET_ERROR_TYPE_INFO,
+    GNUNET_log (GNUNET_ERROR_TYPE_DEBUG,
                 "Received CS key %s (%s)\n",
                 GNUNET_h2s (&h_cs.hash),
                 section_name);
@@ -342,7 +342,7 @@ more:
     msize = ntohs (hdr->size);
     if (off < msize)
       continue;
-    GNUNET_log (GNUNET_ERROR_TYPE_INFO,
+    GNUNET_log (GNUNET_ERROR_TYPE_DEBUG,
                 "Received message of type %u and length %u\n",
                 (unsigned int) ntohs (hdr->type),
                 (unsigned int) msize);
