@@ -388,7 +388,7 @@ GNUNET_NETWORK_STRUCT_BEGIN
 struct TALER_AgeWithdrawConfirmationPS
 {
   /**
-   * Purpose is #TALER_SIGNATURE_EXCHANGE_CONFIRM_AGE_WITHDRAW.   Signed by a
+   * Purpose is #TALER_SIGNATURE_EXCHANGE_CONFIRM_WITHDRAW.   Signed by a
    * `struct TALER_ExchangePublicKeyP` using EdDSA.
    */
   struct GNUNET_CRYPTO_EccSignaturePurpose purpose;
@@ -418,7 +418,7 @@ TALER_exchange_online_age_withdraw_confirmation_sign (
 {
 
   struct TALER_AgeWithdrawConfirmationPS confirm = {
-    .purpose.purpose = htonl (TALER_SIGNATURE_EXCHANGE_CONFIRM_AGE_WITHDRAW),
+    .purpose.purpose = htonl (TALER_SIGNATURE_EXCHANGE_CONFIRM_WITHDRAW),
     .purpose.size = htonl (sizeof (confirm)),
     .h_commitment = *h_commitment,
     .noreveal_index = htonl (noreveal_index)
@@ -438,7 +438,7 @@ TALER_exchange_online_age_withdraw_confirmation_verify (
   const struct TALER_ExchangeSignatureP *exchange_sig)
 {
   struct TALER_AgeWithdrawConfirmationPS confirm = {
-    .purpose.purpose = htonl (TALER_SIGNATURE_EXCHANGE_CONFIRM_AGE_WITHDRAW),
+    .purpose.purpose = htonl (TALER_SIGNATURE_EXCHANGE_CONFIRM_WITHDRAW),
     .purpose.size = htonl (sizeof (confirm)),
     .h_commitment = *h_commitment,
     .noreveal_index = htonl (noreveal_index)
@@ -446,7 +446,7 @@ TALER_exchange_online_age_withdraw_confirmation_verify (
 
   if (GNUNET_OK !=
       GNUNET_CRYPTO_eddsa_verify (
-        TALER_SIGNATURE_EXCHANGE_CONFIRM_AGE_WITHDRAW,
+        TALER_SIGNATURE_EXCHANGE_CONFIRM_WITHDRAW,
         &confirm,
         &exchange_sig->eddsa_signature,
         &exchange_pub->eddsa_pub))
@@ -458,7 +458,7 @@ TALER_exchange_online_age_withdraw_confirmation_verify (
 }
 
 
-/* TODO:oec: add signature for age-withdraw, age-reveal */
+/* FIXME[oec] add signature for age-withdraw, age-reveal */
 
 
 GNUNET_NETWORK_STRUCT_BEGIN
