@@ -21,23 +21,50 @@
 #include "platform.h"
 #include "taler_util.h"
 
-
 /**
- * Check if @a lang matches the @a language_pattern, and if so with
- * which preference.
- * See also: https://tools.ietf.org/html/rfc7231#section-5.3.1
+ * Check if @a value matches the @a accept_pattern.
  *
- * @param language_pattern a language preferences string
- *        like "fr-CH, fr;q=0.9, en;q=0.8, *;q=0.1"
- * @param lang the 2-digit language to match
- * @return q-weight given for @a lang in @a language_pattern, 1.0 if no weights are given;
- *         0 if @a lang is not in @a language_pattern
+ * @param accept_pattern a pattern like "[text|STAR/]*[text|STAR]"
+ * @param value the value to match
+ * @return true if @a value matches the @a accept_pattern
  */
-double
-TALER_language_matches (const char *language_pattern,
-                        const char *lang)
+static bool
+pattern_matches (const char *accept_pattern,
+                 const char *value)
 {
-  char *p = GNUNET_strdup (language_pattern);
+  const char *da;
+  const char *dm;
+
+  if (0 == strcmp ("*",
+                   accept_pattern))
+    return true;
+  if (0 == strcmp (value,
+                   accept_pattern))
+    return true;
+  da = strchr (accept_pattern,
+               '/');
+  dm = strchr (value,
+               '/');
+  if ( (NULL == da) ||
+       (NULL == dm) )
+    return false;
+  if ( ( (1 == da - accept_pattern) &&
+         ('*' == *accept_pattern) ) ||
+       ( (da - accept_pattern == dm - value) &&
+         (0 == strncasecmp (accept_pattern,
+                            value,
+                            da - accept_pattern)) ) )
+    return pattern_matches (da + 1,
+                            dm + 1);
+  return false;
+}
+
+
+double
+TALER_pattern_matches (const char *pattern,
+                       const char *value)
+{
+  char *p = GNUNET_strdup (pattern);
   char *sptr;
   double r = 0.0;
 
@@ -50,8 +77,7 @@ TALER_language_matches (const char *language_pattern,
     char *qp = strtok_r (NULL, ";", &sptr2);
     double q = 1.0;
 
-    if (NULL == lp)
-      continue; /* should be impossible, but makes static analysis happy */
+    GNUNET_assert (NULL != lp);
     while (isspace ((int) *lp))
       lp++;
     if (NULL != qp)
@@ -61,8 +87,8 @@ TALER_language_matches (const char *language_pattern,
                       (1 == sscanf (qp,
                                     "q=%lf",
                                     &q)) );
-    if (0 == strcasecmp (lang,
-                         lp))
+    if (pattern_matches (lp,
+                         value))
       r = GNUNET_MAX (r, q);
   }
   GNUNET_free (p);
