@@ -1485,7 +1485,7 @@ cs_update_client_keys (struct TES_Client *client)
 /**
  * Create a new denomination key (we do not have enough).
  *
- * @param denom denomination key to create
+ * @param[in] denom denomination key to create
  * @param now current time to use (to get many keys to use the exact same time)
  * @return #GNUNET_OK on success
  */
@@ -1505,7 +1505,9 @@ create_key (struct Denomination *denom,
                                     GNUNET_TIME_relative_subtract (
                                       denom->duration_withdraw,
                                       overlap_duration));
-    if (GNUNET_TIME_absolute_cmp (now.abs_time, <, abs))
+    if (GNUNET_TIME_absolute_cmp (now.abs_time,
+                                  <,
+                                  abs))
       anchor = GNUNET_TIME_absolute_to_timestamp (abs);
   }
   dk = GNUNET_new (struct DenominationKey);
