@@ -1225,7 +1225,7 @@ rsa_update_client_keys (struct TES_Client *client)
 /**
  * Create a new denomination key (we do not have enough).
  *
- * @param denom denomination key to create
+ * @param[in] denom denomination key to create
  * @param now current time to use (to get many keys to use the exact same time)
  * @return #GNUNET_OK on success
  */
@@ -1237,7 +1237,6 @@ create_key (struct Denomination *denom,
   struct GNUNET_TIME_Timestamp anchor;
 
   anchor = now;
-  // FIXME: round down to multiple of 'anchor_round' value from configuration
   if (NULL != denom->keys_tail)
   {
     struct GNUNET_TIME_Absolute abs;
@@ -1246,7 +1245,9 @@ create_key (struct Denomination *denom,
                                     GNUNET_TIME_relative_subtract (
                                       denom->duration_withdraw,
                                       overlap_duration));
-    if (GNUNET_TIME_absolute_cmp (now.abs_time, <, abs))
+    if (GNUNET_TIME_absolute_cmp (now.abs_time,
+                                  <,
+                                  abs))
       anchor = GNUNET_TIME_absolute_to_timestamp (abs);
   }
   dk = GNUNET_new (struct DenominationKey);
@@ -1397,7 +1398,9 @@ update_keys (struct Denomination *denom,
          NULL != pos;
          pos = pos->next)
     {
-      if (GNUNET_TIME_absolute_cmp (denomination_action_time (pos), >=, at))
+      if (GNUNET_TIME_absolute_cmp (denomination_action_time (pos),
+                                    >=,
+                                    at))
         break;
       before = pos;
     }
